/* GElementTest.c generated by valac 0.44.3, the Vala compiler
 * generated from GElementTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* Notation.vala
 *
 * Copyright (C) 2016  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib-object.h>
#include <glib.h>
#include <gxml/gxml.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_GELEMENT_TEST (gelement_test_get_type ())
#define GELEMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GELEMENT_TEST, GElementTest))
#define GELEMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GELEMENT_TEST, GElementTestClass))
#define IS_GELEMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GELEMENT_TEST))
#define IS_GELEMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GELEMENT_TEST))
#define GELEMENT_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GELEMENT_TEST, GElementTestClass))

typedef struct _GElementTest GElementTest;
typedef struct _GElementTestClass GElementTestClass;
typedef struct _GElementTestPrivate GElementTestPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _GElementTest {
	GXmlTest parent_instance;
	GElementTestPrivate * priv;
};

struct _GElementTestClass {
	GXmlTestClass parent_class;
};

static gpointer gelement_test_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType gelement_test_get_type (void) G_GNUC_CONST;
void gelement_test_add_tests (void);
static void __lambda28_ (void);
static void ___lambda28__gtest_func (void);
static void __lambda29_ (void);
static void ___lambda29__gtest_func (void);
static void __lambda30_ (void);
static void ___lambda30__gtest_func (void);
static void __lambda31_ (void);
static void ___lambda31__gtest_func (void);
static void __lambda32_ (void);
static void ___lambda32__gtest_func (void);
static void __lambda33_ (void);
static void ___lambda33__gtest_func (void);
static void __lambda34_ (void);
static void ___lambda34__gtest_func (void);
static void __lambda35_ (void);
static void ___lambda35__gtest_func (void);
static void __lambda36_ (void);
static void ___lambda36__gtest_func (void);
static void __lambda37_ (void);
static void ___lambda37__gtest_func (void);
GElementTest* gelement_test_new (void);
GElementTest* gelement_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static void _vala_array_destroy (gpointer array,
                          gint array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gint array_length,
                       GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);

static void
__lambda28_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlGNode* root = NULL;
		GXmlNode* _tmp1_;
		GXmlNode* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		GXmlGNode* node = NULL;
		GeeBidirList* _tmp6_;
		GeeBidirList* _tmp7_;
		GeeBidirList* _tmp8_;
		gpointer _tmp9_;
		GXmlGNode* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		GeeList* _tmp14_;
		GeeList* _tmp15_;
		GeeList* _tmp16_;
		GeeList* _tmp17_;
		GeeList* _tmp18_;
		GeeList* _tmp19_;
		gint _tmp20_;
		gint _tmp21_;
		GeeList* _tmp22_;
		GeeList* _tmp23_;
		GeeList* _tmp24_;
		gpointer _tmp25_;
		GXmlNamespace* _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
		GeeList* _tmp30_;
		GeeList* _tmp31_;
		GeeList* _tmp32_;
		gpointer _tmp33_;
		GXmlNamespace* _tmp34_;
		gchar* _tmp35_;
		gchar* _tmp36_;
		gchar* _tmp37_;
		GeeList* _tmp38_;
		GeeList* _tmp39_;
		GeeList* _tmp40_;
		gpointer _tmp41_;
		GXmlNamespace* _tmp42_;
		gchar* _tmp43_;
		gchar* _tmp44_;
		gchar* _tmp45_;
		GeeList* _tmp46_;
		GeeList* _tmp47_;
		GeeList* _tmp48_;
		gpointer _tmp49_;
		GXmlNamespace* _tmp50_;
		gchar* _tmp51_;
		gchar* _tmp52_;
		gchar* _tmp53_;
#line 29 "GElementTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<Potions><magic:Potion xmlns:magic=\"http://hogwarts.co.uk/magic\" xml" \
"ns:products=\"http://diagonalley.co.uk/products\"/></Potions>", 0, &_inner_error0_);
#line 29 "GElementTest.vala"
		doc = _tmp0_;
#line 29 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 201 "GElementTest.c"
			goto __catch43_g_error;
		}
#line 30 "GElementTest.vala"
		_tmp1_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 30 "GElementTest.vala"
		_tmp2_ = _tmp1_;
#line 30 "GElementTest.vala"
		root = G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GXML_TYPE_GNODE, GXmlGNode);
#line 31 "GElementTest.vala"
		_vala_assert (root != NULL, "root != null");
#line 32 "GElementTest.vala"
		_tmp3_ = gxml_gnode_get_name (root);
#line 32 "GElementTest.vala"
		_tmp4_ = _tmp3_;
#line 32 "GElementTest.vala"
		_tmp5_ = _tmp4_;
#line 32 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp5_, "Potions") == 0, "root.name == \"Potions\"");
#line 32 "GElementTest.vala"
		_g_free0 (_tmp5_);
#line 33 "GElementTest.vala"
		_tmp6_ = gxml_gnode_get_children_nodes (root);
#line 33 "GElementTest.vala"
		_tmp7_ = _tmp6_;
#line 33 "GElementTest.vala"
		_tmp8_ = _tmp7_;
#line 33 "GElementTest.vala"
		_tmp9_ = gee_list_get ((GeeList*) _tmp8_, 0);
#line 33 "GElementTest.vala"
		_tmp10_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlNode*) _tmp9_, GXML_TYPE_GNODE, GXmlGNode);
#line 33 "GElementTest.vala"
		_g_object_unref0 (_tmp8_);
#line 33 "GElementTest.vala"
		node = _tmp10_;
#line 34 "GElementTest.vala"
		_vala_assert (node != NULL, "node != null");
#line 35 "GElementTest.vala"
		_tmp11_ = gxml_gnode_get_name (node);
#line 35 "GElementTest.vala"
		_tmp12_ = _tmp11_;
#line 35 "GElementTest.vala"
		_tmp13_ = _tmp12_;
#line 35 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp13_, "Potion") == 0, "node.name == \"Potion\"");
#line 35 "GElementTest.vala"
		_g_free0 (_tmp13_);
#line 36 "GElementTest.vala"
		_tmp14_ = gxml_gnode_get_namespaces (node);
#line 36 "GElementTest.vala"
		_tmp15_ = _tmp14_;
#line 36 "GElementTest.vala"
		_tmp16_ = _tmp15_;
#line 36 "GElementTest.vala"
		_vala_assert (_tmp16_ != NULL, "node.namespaces != null");
#line 36 "GElementTest.vala"
		_g_object_unref0 (_tmp16_);
#line 37 "GElementTest.vala"
		_tmp17_ = gxml_gnode_get_namespaces (node);
#line 37 "GElementTest.vala"
		_tmp18_ = _tmp17_;
#line 37 "GElementTest.vala"
		_tmp19_ = _tmp18_;
#line 37 "GElementTest.vala"
		_tmp20_ = gee_collection_get_size ((GeeCollection*) _tmp19_);
#line 37 "GElementTest.vala"
		_tmp21_ = _tmp20_;
#line 37 "GElementTest.vala"
		_vala_assert (_tmp21_ == 2, "node.namespaces.size == 2");
#line 37 "GElementTest.vala"
		_g_object_unref0 (_tmp19_);
#line 38 "GElementTest.vala"
		_tmp22_ = gxml_gnode_get_namespaces (node);
#line 38 "GElementTest.vala"
		_tmp23_ = _tmp22_;
#line 38 "GElementTest.vala"
		_tmp24_ = _tmp23_;
#line 38 "GElementTest.vala"
		_tmp25_ = gee_list_get (_tmp24_, 0);
#line 38 "GElementTest.vala"
		_tmp26_ = (GXmlNamespace*) _tmp25_;
#line 38 "GElementTest.vala"
		_tmp27_ = gxml_namespace_get_uri (_tmp26_);
#line 38 "GElementTest.vala"
		_tmp28_ = _tmp27_;
#line 38 "GElementTest.vala"
		_tmp29_ = _tmp28_;
#line 38 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp29_, "http://hogwarts.co.uk/magic") == 0, "node.namespaces[0].uri == \"http://hogwarts.co.uk/magic\"");
#line 38 "GElementTest.vala"
		_g_free0 (_tmp29_);
#line 38 "GElementTest.vala"
		_g_object_unref0 (_tmp26_);
#line 38 "GElementTest.vala"
		_g_object_unref0 (_tmp24_);
#line 39 "GElementTest.vala"
		_tmp30_ = gxml_gnode_get_namespaces (node);
#line 39 "GElementTest.vala"
		_tmp31_ = _tmp30_;
#line 39 "GElementTest.vala"
		_tmp32_ = _tmp31_;
#line 39 "GElementTest.vala"
		_tmp33_ = gee_list_get (_tmp32_, 0);
#line 39 "GElementTest.vala"
		_tmp34_ = (GXmlNamespace*) _tmp33_;
#line 39 "GElementTest.vala"
		_tmp35_ = gxml_namespace_get_prefix (_tmp34_);
#line 39 "GElementTest.vala"
		_tmp36_ = _tmp35_;
#line 39 "GElementTest.vala"
		_tmp37_ = _tmp36_;
#line 39 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp37_, "magic") == 0, "node.namespaces[0].prefix == \"magic\"");
#line 39 "GElementTest.vala"
		_g_free0 (_tmp37_);
#line 39 "GElementTest.vala"
		_g_object_unref0 (_tmp34_);
#line 39 "GElementTest.vala"
		_g_object_unref0 (_tmp32_);
#line 40 "GElementTest.vala"
		_tmp38_ = gxml_gnode_get_namespaces (node);
#line 40 "GElementTest.vala"
		_tmp39_ = _tmp38_;
#line 40 "GElementTest.vala"
		_tmp40_ = _tmp39_;
#line 40 "GElementTest.vala"
		_tmp41_ = gee_list_get (_tmp40_, 1);
#line 40 "GElementTest.vala"
		_tmp42_ = (GXmlNamespace*) _tmp41_;
#line 40 "GElementTest.vala"
		_tmp43_ = gxml_namespace_get_prefix (_tmp42_);
#line 40 "GElementTest.vala"
		_tmp44_ = _tmp43_;
#line 40 "GElementTest.vala"
		_tmp45_ = _tmp44_;
#line 40 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp45_, "products") == 0, "node.namespaces.get (1).prefix == \"products\"");
#line 40 "GElementTest.vala"
		_g_free0 (_tmp45_);
#line 40 "GElementTest.vala"
		_g_object_unref0 (_tmp42_);
#line 40 "GElementTest.vala"
		_g_object_unref0 (_tmp40_);
#line 41 "GElementTest.vala"
		_tmp46_ = gxml_gnode_get_namespaces (node);
#line 41 "GElementTest.vala"
		_tmp47_ = _tmp46_;
#line 41 "GElementTest.vala"
		_tmp48_ = _tmp47_;
#line 41 "GElementTest.vala"
		_tmp49_ = gee_list_get (_tmp48_, 1);
#line 41 "GElementTest.vala"
		_tmp50_ = (GXmlNamespace*) _tmp49_;
#line 41 "GElementTest.vala"
		_tmp51_ = gxml_namespace_get_uri (_tmp50_);
#line 41 "GElementTest.vala"
		_tmp52_ = _tmp51_;
#line 41 "GElementTest.vala"
		_tmp53_ = _tmp52_;
#line 41 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp53_, "http://diagonalley.co.uk/products") == 0, "node.namespaces.get (1).uri == \"http://diagonalley.co.uk/products\"");
#line 41 "GElementTest.vala"
		_g_free0 (_tmp53_);
#line 41 "GElementTest.vala"
		_g_object_unref0 (_tmp50_);
#line 41 "GElementTest.vala"
		_g_object_unref0 (_tmp48_);
#line 28 "GElementTest.vala"
		_g_object_unref0 (node);
#line 28 "GElementTest.vala"
		_g_object_unref0 (root);
#line 28 "GElementTest.vala"
		_g_object_unref0 (doc);
#line 374 "GElementTest.c"
	}
	goto __finally43;
	__catch43_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp54_;
#line 28 "GElementTest.vala"
		e = _inner_error0_;
#line 28 "GElementTest.vala"
		_inner_error0_ = NULL;
#line 43 "GElementTest.vala"
		_tmp54_ = e->message;
#line 43 "GElementTest.vala"
		g_test_message ("%s", _tmp54_);
#line 44 "GElementTest.vala"
		g_assert_not_reached ();
#line 28 "GElementTest.vala"
		_g_error_free0 (e);
#line 393 "GElementTest.c"
	}
	__finally43:
#line 28 "GElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 28 "GElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 28 "GElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 28 "GElementTest.vala"
		return;
#line 404 "GElementTest.c"
	}
}

static void
___lambda28__gtest_func (void)
{
#line 27 "GElementTest.vala"
	__lambda28_ ();
#line 413 "GElementTest.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 51 "GElementTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 421 "GElementTest.c"
}

static void
__lambda29_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlGDocument* _tmp1_;
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_ = NULL;
		GXmlGDocument* _tmp6_;
		GXmlNode* _tmp7_;
		GXmlGElement* elem = NULL;
		GXmlGElement* _tmp8_;
		GXmlGDocument* _tmp9_;
		GXmlNode* _tmp10_;
		GXmlNode* _tmp11_;
		GXmlNode* _tmp12_;
		GeeBidirList* _tmp13_;
		GeeBidirList* _tmp14_;
		GeeBidirList* _tmp15_;
		GeeMap* _tmp16_;
		GeeMap* _tmp17_;
		GeeMap* _tmp18_;
		GeeMap* _tmp19_;
		GeeMap* _tmp20_;
		GeeMap* _tmp21_;
		gint _tmp22_;
		gint _tmp23_;
		GeeMap* _tmp24_;
		GeeMap* _tmp25_;
		GeeMap* _tmp26_;
		gint _tmp27_;
		gint _tmp28_;
		GXmlGDocument* _tmp29_;
		gchar* _tmp30_;
		gchar* _tmp31_;
		gchar* _tmp32_;
		gchar* _tmp33_;
		GeeMap* _tmp34_;
		GeeMap* _tmp35_;
		GeeMap* _tmp36_;
		gpointer _tmp37_;
		GXmlNode* _tmp38_;
		gchar* _tmp39_;
		gchar* _tmp40_;
		gchar* _tmp41_;
		GeeMap* _tmp42_;
		GeeMap* _tmp43_;
		GeeMap* _tmp44_;
		gpointer _tmp45_;
		GXmlNode* _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
		gchar* _tmp49_;
		GXmlGAttribute* attr = NULL;
		GXmlNode* _tmp50_;
		GXmlGAttribute* _tmp51_;
		GeeMap* _tmp52_;
		GeeMap* _tmp53_;
		GeeMap* _tmp54_;
		gint _tmp55_;
		gint _tmp56_;
		GeeMap* _tmp57_;
		GeeMap* _tmp58_;
		GeeMap* _tmp59_;
		gpointer _tmp60_;
		GXmlNode* _tmp61_;
		gchar* _tmp62_;
		gchar* _tmp63_;
		gchar* _tmp64_;
		GeeMap* _tmp65_;
		GeeMap* _tmp66_;
		GeeMap* _tmp67_;
		GeeMap* _tmp68_;
		GeeMap* _tmp69_;
		GeeMap* _tmp70_;
		gpointer _tmp71_;
		GXmlNode* _tmp72_;
		GeeMap* _tmp73_;
		GeeMap* _tmp74_;
		GeeMap* _tmp75_;
		gint _tmp76_;
		gint _tmp77_;
		GeeMap* _tmp78_;
		GeeMap* _tmp79_;
		GeeMap* _tmp80_;
		gint _tmp81_;
		gint _tmp82_;
#line 49 "GElementTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<root />", 0, &_inner_error0_);
#line 49 "GElementTest.vala"
		doc = _tmp0_;
#line 49 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 521 "GElementTest.c"
			goto __catch44_g_error;
		}
#line 50 "GElementTest.vala"
		_tmp1_ = doc;
#line 50 "GElementTest.vala"
		_tmp2_ = gxml_document_get_root ((GXmlDocument*) _tmp1_);
#line 50 "GElementTest.vala"
		_tmp3_ = _tmp2_;
#line 50 "GElementTest.vala"
		_tmp4_ = _tmp3_;
#line 50 "GElementTest.vala"
		_vala_assert (_tmp4_ != NULL, "doc.root != null");
#line 50 "GElementTest.vala"
		_g_object_unref0 (_tmp4_);
#line 51 "GElementTest.vala"
		_tmp6_ = doc;
#line 51 "GElementTest.vala"
		_tmp7_ = gxml_document_create_element ((GXmlDocument*) _tmp6_, "alphanumeric", &_inner_error0_);
#line 51 "GElementTest.vala"
		_tmp5_ = _tmp7_;
#line 51 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 51 "GElementTest.vala"
			_g_object_unref0 (doc);
#line 546 "GElementTest.c"
			goto __catch44_g_error;
		}
#line 51 "GElementTest.vala"
		_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GXML_TYPE_GELEMENT, GXmlGElement));
#line 51 "GElementTest.vala"
		elem = _tmp8_;
#line 52 "GElementTest.vala"
		_tmp9_ = doc;
#line 52 "GElementTest.vala"
		_tmp10_ = gxml_document_get_root ((GXmlDocument*) _tmp9_);
#line 52 "GElementTest.vala"
		_tmp11_ = _tmp10_;
#line 52 "GElementTest.vala"
		_tmp12_ = _tmp11_;
#line 52 "GElementTest.vala"
		_tmp13_ = gxml_node_get_children_nodes (_tmp12_);
#line 52 "GElementTest.vala"
		_tmp14_ = _tmp13_;
#line 52 "GElementTest.vala"
		_tmp15_ = _tmp14_;
#line 52 "GElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp15_, (GXmlNode*) elem);
#line 52 "GElementTest.vala"
		_g_object_unref0 (_tmp15_);
#line 52 "GElementTest.vala"
		_g_object_unref0 (_tmp12_);
#line 53 "GElementTest.vala"
		_tmp16_ = gxml_gnode_get_attrs ((GXmlGNode*) elem);
#line 53 "GElementTest.vala"
		_tmp17_ = _tmp16_;
#line 53 "GElementTest.vala"
		_tmp18_ = _tmp17_;
#line 53 "GElementTest.vala"
		_vala_assert (_tmp18_ != NULL, "elem.attrs != null");
#line 53 "GElementTest.vala"
		_g_object_unref0 (_tmp18_);
#line 54 "GElementTest.vala"
		_tmp19_ = gxml_gnode_get_attrs ((GXmlGNode*) elem);
#line 54 "GElementTest.vala"
		_tmp20_ = _tmp19_;
#line 54 "GElementTest.vala"
		_tmp21_ = _tmp20_;
#line 54 "GElementTest.vala"
		_tmp22_ = gee_map_get_size (_tmp21_);
#line 54 "GElementTest.vala"
		_tmp23_ = _tmp22_;
#line 54 "GElementTest.vala"
		_vala_assert (_tmp23_ == 0, "elem.attrs.size == 0");
#line 54 "GElementTest.vala"
		_g_object_unref0 (_tmp21_);
#line 55 "GElementTest.vala"
		gxml_element_set_attr ((GXmlElement*) elem, "alley", "Diagon");
#line 56 "GElementTest.vala"
		gxml_element_set_attr ((GXmlElement*) elem, "train", "Hogwarts Express");
#line 57 "GElementTest.vala"
		_tmp24_ = gxml_gnode_get_attrs ((GXmlGNode*) elem);
#line 57 "GElementTest.vala"
		_tmp25_ = _tmp24_;
#line 57 "GElementTest.vala"
		_tmp26_ = _tmp25_;
#line 57 "GElementTest.vala"
		_tmp27_ = gee_map_get_size (_tmp26_);
#line 57 "GElementTest.vala"
		_tmp28_ = _tmp27_;
#line 57 "GElementTest.vala"
		_vala_assert (_tmp28_ == 2, "elem.attrs.size == 2");
#line 57 "GElementTest.vala"
		_g_object_unref0 (_tmp26_);
#line 58 "GElementTest.vala"
		_tmp29_ = doc;
#line 58 "GElementTest.vala"
		_tmp30_ = gxml_gnode_to_string ((GXmlGNode*) _tmp29_);
#line 58 "GElementTest.vala"
		_tmp31_ = _tmp30_;
#line 58 "GElementTest.vala"
		_tmp32_ = g_strconcat ("Getting attributes value alley... Node: ", _tmp31_, NULL);
#line 58 "GElementTest.vala"
		_tmp33_ = _tmp32_;
#line 58 "GElementTest.vala"
		g_test_message ("%s", _tmp33_);
#line 58 "GElementTest.vala"
		_g_free0 (_tmp33_);
#line 58 "GElementTest.vala"
		_g_free0 (_tmp31_);
#line 59 "GElementTest.vala"
		_tmp34_ = gxml_gnode_get_attrs ((GXmlGNode*) elem);
#line 59 "GElementTest.vala"
		_tmp35_ = _tmp34_;
#line 59 "GElementTest.vala"
		_tmp36_ = _tmp35_;
#line 59 "GElementTest.vala"
		_tmp37_ = gee_map_get (_tmp36_, "alley");
#line 59 "GElementTest.vala"
		_tmp38_ = (GXmlNode*) _tmp37_;
#line 59 "GElementTest.vala"
		_tmp39_ = gxml_node_get_value (_tmp38_);
#line 59 "GElementTest.vala"
		_tmp40_ = _tmp39_;
#line 59 "GElementTest.vala"
		_tmp41_ = _tmp40_;
#line 59 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp41_, "Diagon") == 0, "elem.attrs.get (\"alley\").value == \"Diagon\"");
#line 59 "GElementTest.vala"
		_g_free0 (_tmp41_);
#line 59 "GElementTest.vala"
		_g_object_unref0 (_tmp38_);
#line 59 "GElementTest.vala"
		_g_object_unref0 (_tmp36_);
#line 60 "GElementTest.vala"
		_tmp42_ = gxml_gnode_get_attrs ((GXmlGNode*) elem);
#line 60 "GElementTest.vala"
		_tmp43_ = _tmp42_;
#line 60 "GElementTest.vala"
		_tmp44_ = _tmp43_;
#line 60 "GElementTest.vala"
		_tmp45_ = gee_map_get (_tmp44_, "train");
#line 60 "GElementTest.vala"
		_tmp46_ = (GXmlNode*) _tmp45_;
#line 60 "GElementTest.vala"
		_tmp47_ = gxml_node_get_value (_tmp46_);
#line 60 "GElementTest.vala"
		_tmp48_ = _tmp47_;
#line 60 "GElementTest.vala"
		_tmp49_ = _tmp48_;
#line 60 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp49_, "Hogwarts Express") == 0, "elem.attrs.get (\"train\").value == \"Hogwarts Express\"");
#line 60 "GElementTest.vala"
		_g_free0 (_tmp49_);
#line 60 "GElementTest.vala"
		_g_object_unref0 (_tmp46_);
#line 60 "GElementTest.vala"
		_g_object_unref0 (_tmp44_);
#line 62 "GElementTest.vala"
		gxml_element_set_attr ((GXmlElement*) elem, "owl", "");
#line 63 "GElementTest.vala"
		_tmp50_ = gxml_element_get_attr ((GXmlElement*) elem, "owl");
#line 63 "GElementTest.vala"
		_tmp51_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp50_, GXML_TYPE_GATTRIBUTE) ? ((GXmlGAttribute*) _tmp50_) : NULL;
#line 63 "GElementTest.vala"
		if (_tmp51_ == NULL) {
#line 63 "GElementTest.vala"
			_g_object_unref0 (_tmp50_);
#line 689 "GElementTest.c"
		}
#line 63 "GElementTest.vala"
		attr = _tmp51_;
#line 64 "GElementTest.vala"
		_vala_assert (attr != NULL, "attr != null");
#line 65 "GElementTest.vala"
		gxml_dom_attr_set_value ((GXmlDomAttr*) attr, "Hedwig");
#line 67 "GElementTest.vala"
		_tmp52_ = gxml_gnode_get_attrs ((GXmlGNode*) elem);
#line 67 "GElementTest.vala"
		_tmp53_ = _tmp52_;
#line 67 "GElementTest.vala"
		_tmp54_ = _tmp53_;
#line 67 "GElementTest.vala"
		_tmp55_ = gee_map_get_size (_tmp54_);
#line 67 "GElementTest.vala"
		_tmp56_ = _tmp55_;
#line 67 "GElementTest.vala"
		_vala_assert (_tmp56_ == 3, "elem.attrs.size == 3");
#line 67 "GElementTest.vala"
		_g_object_unref0 (_tmp54_);
#line 68 "GElementTest.vala"
		_tmp57_ = gxml_gnode_get_attrs ((GXmlGNode*) elem);
#line 68 "GElementTest.vala"
		_tmp58_ = _tmp57_;
#line 68 "GElementTest.vala"
		_tmp59_ = _tmp58_;
#line 68 "GElementTest.vala"
		_tmp60_ = gee_map_get (_tmp59_, "owl");
#line 68 "GElementTest.vala"
		_tmp61_ = (GXmlNode*) _tmp60_;
#line 68 "GElementTest.vala"
		_tmp62_ = gxml_node_get_value (_tmp61_);
#line 68 "GElementTest.vala"
		_tmp63_ = _tmp62_;
#line 68 "GElementTest.vala"
		_tmp64_ = _tmp63_;
#line 68 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp64_, "Hedwig") == 0, "elem.attrs.get (\"owl\").value == \"Hedwig\"");
#line 68 "GElementTest.vala"
		_g_free0 (_tmp64_);
#line 68 "GElementTest.vala"
		_g_object_unref0 (_tmp61_);
#line 68 "GElementTest.vala"
		_g_object_unref0 (_tmp59_);
#line 70 "GElementTest.vala"
		_tmp65_ = gxml_gnode_get_attrs ((GXmlGNode*) elem);
#line 70 "GElementTest.vala"
		_tmp66_ = _tmp65_;
#line 70 "GElementTest.vala"
		_tmp67_ = _tmp66_;
#line 70 "GElementTest.vala"
		gee_map_unset (_tmp67_, "alley", NULL);
#line 70 "GElementTest.vala"
		_g_object_unref0 (_tmp67_);
#line 71 "GElementTest.vala"
		_tmp68_ = gxml_gnode_get_attrs ((GXmlGNode*) elem);
#line 71 "GElementTest.vala"
		_tmp69_ = _tmp68_;
#line 71 "GElementTest.vala"
		_tmp70_ = _tmp69_;
#line 71 "GElementTest.vala"
		_tmp71_ = gee_map_get (_tmp70_, "alley");
#line 71 "GElementTest.vala"
		_tmp72_ = (GXmlNode*) _tmp71_;
#line 71 "GElementTest.vala"
		_vala_assert (_tmp72_ == NULL, "elem.attrs.get (\"alley\") == null");
#line 71 "GElementTest.vala"
		_g_object_unref0 (_tmp72_);
#line 71 "GElementTest.vala"
		_g_object_unref0 (_tmp70_);
#line 72 "GElementTest.vala"
		_tmp73_ = gxml_gnode_get_attrs ((GXmlGNode*) elem);
#line 72 "GElementTest.vala"
		_tmp74_ = _tmp73_;
#line 72 "GElementTest.vala"
		_tmp75_ = _tmp74_;
#line 72 "GElementTest.vala"
		_tmp76_ = gee_map_get_size (_tmp75_);
#line 72 "GElementTest.vala"
		_tmp77_ = _tmp76_;
#line 72 "GElementTest.vala"
		_vala_assert (_tmp77_ == 2, "elem.attrs.size == 2");
#line 72 "GElementTest.vala"
		_g_object_unref0 (_tmp75_);
#line 73 "GElementTest.vala"
		gxml_element_remove_attr ((GXmlElement*) elem, "owl");
#line 74 "GElementTest.vala"
		_tmp78_ = gxml_gnode_get_attrs ((GXmlGNode*) elem);
#line 74 "GElementTest.vala"
		_tmp79_ = _tmp78_;
#line 74 "GElementTest.vala"
		_tmp80_ = _tmp79_;
#line 74 "GElementTest.vala"
		_tmp81_ = gee_map_get_size (_tmp80_);
#line 74 "GElementTest.vala"
		_tmp82_ = _tmp81_;
#line 74 "GElementTest.vala"
		_vala_assert (_tmp82_ == 1, "elem.attrs.size == 1");
#line 74 "GElementTest.vala"
		_g_object_unref0 (_tmp80_);
#line 48 "GElementTest.vala"
		_g_object_unref0 (attr);
#line 48 "GElementTest.vala"
		_g_object_unref0 (elem);
#line 48 "GElementTest.vala"
		_g_object_unref0 (_tmp5_);
#line 48 "GElementTest.vala"
		_g_object_unref0 (doc);
#line 799 "GElementTest.c"
	}
	goto __finally44;
	__catch44_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp83_;
#line 48 "GElementTest.vala"
		e = _inner_error0_;
#line 48 "GElementTest.vala"
		_inner_error0_ = NULL;
#line 76 "GElementTest.vala"
		_tmp83_ = e->message;
#line 76 "GElementTest.vala"
		g_test_message ("%s", _tmp83_);
#line 77 "GElementTest.vala"
		g_assert_not_reached ();
#line 48 "GElementTest.vala"
		_g_error_free0 (e);
#line 818 "GElementTest.c"
	}
	__finally44:
#line 48 "GElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 48 "GElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 48 "GElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 48 "GElementTest.vala"
		return;
#line 829 "GElementTest.c"
	}
}

static void
___lambda29__gtest_func (void)
{
#line 47 "GElementTest.vala"
	__lambda29_ ();
#line 838 "GElementTest.c"
}

static void
__lambda30_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlNode* elem = NULL;
		GXmlGDocument* _tmp1_;
		GXmlNode* _tmp2_;
		GXmlNode* t = NULL;
		GXmlGDocument* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		GeeBidirList* _tmp7_;
		GeeBidirList* _tmp8_;
		GeeBidirList* _tmp9_;
		GXmlNode* _tmp10_;
		GXmlNode* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		GXmlNode* _tmp16_;
		gchar* _tmp17_;
		gchar* _tmp18_;
		GXmlNode* elem2 = NULL;
		GXmlGDocument* _tmp19_;
		GXmlNode* _tmp20_;
		GXmlNode* t2 = NULL;
		GXmlGDocument* _tmp21_;
		GXmlNode* _tmp22_;
		GXmlNode* _tmp23_;
		GeeBidirList* _tmp24_;
		GeeBidirList* _tmp25_;
		GeeBidirList* _tmp26_;
		GXmlNode* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
		gchar* _tmp30_;
		gchar* _tmp31_;
		GXmlNode* _tmp32_;
		gchar* _tmp33_;
		gchar* _tmp34_;
#line 82 "GElementTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<root />", 0, &_inner_error0_);
#line 82 "GElementTest.vala"
		doc = _tmp0_;
#line 82 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 892 "GElementTest.c"
			goto __catch45_g_error;
		}
#line 83 "GElementTest.vala"
		_tmp1_ = doc;
#line 83 "GElementTest.vala"
		_tmp2_ = gxml_document_create_element ((GXmlDocument*) _tmp1_, "country", &_inner_error0_);
#line 83 "GElementTest.vala"
		elem = _tmp2_;
#line 83 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 83 "GElementTest.vala"
			_g_object_unref0 (doc);
#line 905 "GElementTest.c"
			goto __catch45_g_error;
		}
#line 84 "GElementTest.vala"
		_tmp3_ = doc;
#line 84 "GElementTest.vala"
		_tmp4_ = gxml_document_create_text ((GXmlDocument*) _tmp3_, "New Zealand");
#line 84 "GElementTest.vala"
		t = _tmp4_;
#line 85 "GElementTest.vala"
		_tmp5_ = t;
#line 85 "GElementTest.vala"
		_vala_assert (_tmp5_ != NULL, "t != null");
#line 86 "GElementTest.vala"
		_tmp6_ = elem;
#line 86 "GElementTest.vala"
		_tmp7_ = gxml_node_get_children_nodes (_tmp6_);
#line 86 "GElementTest.vala"
		_tmp8_ = _tmp7_;
#line 86 "GElementTest.vala"
		_tmp9_ = _tmp8_;
#line 86 "GElementTest.vala"
		_tmp10_ = t;
#line 86 "GElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp9_, _tmp10_);
#line 86 "GElementTest.vala"
		_g_object_unref0 (_tmp9_);
#line 87 "GElementTest.vala"
		_tmp11_ = elem;
#line 87 "GElementTest.vala"
		_tmp12_ = gxml_node_to_string (_tmp11_);
#line 87 "GElementTest.vala"
		_tmp13_ = _tmp12_;
#line 87 "GElementTest.vala"
		_tmp14_ = g_strconcat ("Elem1:", _tmp13_, NULL);
#line 87 "GElementTest.vala"
		_tmp15_ = _tmp14_;
#line 87 "GElementTest.vala"
		g_test_message ("%s", _tmp15_);
#line 87 "GElementTest.vala"
		_g_free0 (_tmp15_);
#line 87 "GElementTest.vala"
		_g_free0 (_tmp13_);
#line 88 "GElementTest.vala"
		_tmp16_ = elem;
#line 88 "GElementTest.vala"
		_tmp17_ = gxml_node_to_string (_tmp16_);
#line 88 "GElementTest.vala"
		_tmp18_ = _tmp17_;
#line 88 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp18_, "<country>New Zealand</country>") == 0, "elem.to_string () == \"<country>New Zealand</country>\"");
#line 88 "GElementTest.vala"
		_g_free0 (_tmp18_);
#line 89 "GElementTest.vala"
		_tmp19_ = doc;
#line 89 "GElementTest.vala"
		_tmp20_ = gxml_document_create_element ((GXmlDocument*) _tmp19_, "messy", &_inner_error0_);
#line 89 "GElementTest.vala"
		elem2 = _tmp20_;
#line 89 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 89 "GElementTest.vala"
			_g_object_unref0 (t);
#line 89 "GElementTest.vala"
			_g_object_unref0 (elem);
#line 89 "GElementTest.vala"
			_g_object_unref0 (doc);
#line 972 "GElementTest.c"
			goto __catch45_g_error;
		}
#line 90 "GElementTest.vala"
		_tmp21_ = doc;
#line 90 "GElementTest.vala"
		_tmp22_ = gxml_document_create_text ((GXmlDocument*) _tmp21_, "&lt;<>&gt;");
#line 90 "GElementTest.vala"
		t2 = _tmp22_;
#line 91 "GElementTest.vala"
		_tmp23_ = elem2;
#line 91 "GElementTest.vala"
		_tmp24_ = gxml_node_get_children_nodes (_tmp23_);
#line 91 "GElementTest.vala"
		_tmp25_ = _tmp24_;
#line 91 "GElementTest.vala"
		_tmp26_ = _tmp25_;
#line 91 "GElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp26_, t2);
#line 91 "GElementTest.vala"
		_g_object_unref0 (_tmp26_);
#line 92 "GElementTest.vala"
		_tmp27_ = elem2;
#line 92 "GElementTest.vala"
		_tmp28_ = gxml_node_to_string (_tmp27_);
#line 92 "GElementTest.vala"
		_tmp29_ = _tmp28_;
#line 92 "GElementTest.vala"
		_tmp30_ = g_strconcat ("Elem2:", _tmp29_, NULL);
#line 92 "GElementTest.vala"
		_tmp31_ = _tmp30_;
#line 92 "GElementTest.vala"
		g_test_message ("%s", _tmp31_);
#line 92 "GElementTest.vala"
		_g_free0 (_tmp31_);
#line 92 "GElementTest.vala"
		_g_free0 (_tmp29_);
#line 93 "GElementTest.vala"
		_tmp32_ = elem2;
#line 93 "GElementTest.vala"
		_tmp33_ = gxml_node_to_string (_tmp32_);
#line 93 "GElementTest.vala"
		_tmp34_ = _tmp33_;
#line 93 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "<messy>&amp;lt;&lt;&gt;&amp;gt;</messy>") == 0, "elem2.to_string () == \"<messy>&amp;lt;&lt;&gt;&amp;gt;</messy>\"");
#line 93 "GElementTest.vala"
		_g_free0 (_tmp34_);
#line 81 "GElementTest.vala"
		_g_object_unref0 (t2);
#line 81 "GElementTest.vala"
		_g_object_unref0 (elem2);
#line 81 "GElementTest.vala"
		_g_object_unref0 (t);
#line 81 "GElementTest.vala"
		_g_object_unref0 (elem);
#line 81 "GElementTest.vala"
		_g_object_unref0 (doc);
#line 1029 "GElementTest.c"
	}
	goto __finally45;
	__catch45_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp35_;
#line 81 "GElementTest.vala"
		e = _inner_error0_;
#line 81 "GElementTest.vala"
		_inner_error0_ = NULL;
#line 95 "GElementTest.vala"
		_tmp35_ = e->message;
#line 95 "GElementTest.vala"
		g_test_message ("%s", _tmp35_);
#line 96 "GElementTest.vala"
		g_assert_not_reached ();
#line 81 "GElementTest.vala"
		_g_error_free0 (e);
#line 1048 "GElementTest.c"
	}
	__finally45:
#line 81 "GElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 81 "GElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 81 "GElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 81 "GElementTest.vala"
		return;
#line 1059 "GElementTest.c"
	}
}

static void
___lambda30__gtest_func (void)
{
#line 80 "GElementTest.vala"
	__lambda30_ ();
#line 1068 "GElementTest.c"
}

static void
__lambda31_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlNode* _tmp1_ = NULL;
		GXmlNode* _tmp2_;
		GXmlGElement* root = NULL;
		GXmlGElement* _tmp3_;
		GeeBidirList* _tmp4_;
		GeeBidirList* _tmp5_;
		GeeBidirList* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* s = NULL;
		gchar* _tmp9_;
		gchar* _tmp10_;
		gchar** _tmp11_;
		gchar** _tmp12_;
		gchar** _tmp13_;
		gint _tmp13__length1;
		const gchar* _tmp14_;
		gchar* _tmp15_;
		gchar* _tmp16_;
#line 101 "GElementTest.vala"
		_tmp0_ = gxml_gdocument_new ();
#line 101 "GElementTest.vala"
		doc = _tmp0_;
#line 102 "GElementTest.vala"
		_tmp2_ = gxml_document_create_element ((GXmlDocument*) doc, "root", &_inner_error0_);
#line 102 "GElementTest.vala"
		_tmp1_ = _tmp2_;
#line 102 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 102 "GElementTest.vala"
			_g_object_unref0 (doc);
#line 1109 "GElementTest.c"
			goto __catch46_g_error;
		}
#line 102 "GElementTest.vala"
		_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_GELEMENT, GXmlGElement));
#line 102 "GElementTest.vala"
		root = _tmp3_;
#line 103 "GElementTest.vala"
		_tmp4_ = gxml_gnode_get_children_nodes ((GXmlGNode*) doc);
#line 103 "GElementTest.vala"
		_tmp5_ = _tmp4_;
#line 103 "GElementTest.vala"
		_tmp6_ = _tmp5_;
#line 103 "GElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp6_, (GXmlNode*) G_TYPE_CHECK_INSTANCE_CAST (root, GXML_TYPE_GNODE, GXmlGNode));
#line 103 "GElementTest.vala"
		_g_object_unref0 (_tmp6_);
#line 104 "GElementTest.vala"
		gxml_element_set_content ((GXmlElement*) root, "TEXT1");
#line 105 "GElementTest.vala"
		_tmp7_ = gxml_gnode_to_string ((GXmlGNode*) root);
#line 105 "GElementTest.vala"
		_tmp8_ = _tmp7_;
#line 105 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp8_, "<root>TEXT1</root>") == 0, "root.to_string () == \"<root>TEXT1</root>\"");
#line 105 "GElementTest.vala"
		_g_free0 (_tmp8_);
#line 106 "GElementTest.vala"
		_tmp9_ = gxml_gnode_to_string ((GXmlGNode*) doc);
#line 106 "GElementTest.vala"
		_tmp10_ = _tmp9_;
#line 106 "GElementTest.vala"
		_tmp12_ = _tmp11_ = g_strsplit (_tmp10_, "\n", 0);
#line 106 "GElementTest.vala"
		_tmp13_ = _tmp12_;
#line 106 "GElementTest.vala"
		_tmp13__length1 = _vala_array_length (_tmp11_);
#line 106 "GElementTest.vala"
		_tmp14_ = _tmp13_[1];
#line 106 "GElementTest.vala"
		_tmp15_ = g_strdup (_tmp14_);
#line 106 "GElementTest.vala"
		_tmp16_ = _tmp15_;
#line 106 "GElementTest.vala"
		_tmp13_ = (_vala_array_free (_tmp13_, _tmp13__length1, (GDestroyNotify) g_free), NULL);
#line 106 "GElementTest.vala"
		_g_free0 (_tmp10_);
#line 106 "GElementTest.vala"
		s = _tmp16_;
#line 107 "GElementTest.vala"
		_vala_assert (g_strcmp0 (s, "<root>TEXT1</root>") == 0, "s == \"<root>TEXT1</root>\"");
#line 100 "GElementTest.vala"
		_g_free0 (s);
#line 100 "GElementTest.vala"
		_g_object_unref0 (root);
#line 100 "GElementTest.vala"
		_g_object_unref0 (_tmp1_);
#line 100 "GElementTest.vala"
		_g_object_unref0 (doc);
#line 1168 "GElementTest.c"
	}
	goto __finally46;
	__catch46_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp17_;
#line 100 "GElementTest.vala"
		e = _inner_error0_;
#line 100 "GElementTest.vala"
		_inner_error0_ = NULL;
#line 109 "GElementTest.vala"
		_tmp17_ = e->message;
#line 109 "GElementTest.vala"
		g_test_message ("%s", _tmp17_);
#line 110 "GElementTest.vala"
		g_assert_not_reached ();
#line 100 "GElementTest.vala"
		_g_error_free0 (e);
#line 1187 "GElementTest.c"
	}
	__finally46:
#line 100 "GElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 100 "GElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 100 "GElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 100 "GElementTest.vala"
		return;
#line 1198 "GElementTest.c"
	}
}

static void
___lambda31__gtest_func (void)
{
#line 99 "GElementTest.vala"
	__lambda31_ ();
#line 1207 "GElementTest.c"
}

static void
__lambda32_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlNode* _tmp1_ = NULL;
		GXmlGDocument* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlGElement* root = NULL;
		GXmlGElement* _tmp4_;
		GXmlGDocument* _tmp5_;
		GeeBidirList* _tmp6_;
		GeeBidirList* _tmp7_;
		GeeBidirList* _tmp8_;
		GXmlGElement* _tmp9_;
		GXmlNode* _tmp10_ = NULL;
		GXmlGDocument* _tmp11_;
		GXmlNode* _tmp12_;
		GXmlGElement* n = NULL;
		GXmlGElement* _tmp13_;
		GXmlGElement* _tmp14_;
		GeeBidirList* _tmp15_;
		GeeBidirList* _tmp16_;
		GeeBidirList* _tmp17_;
		GXmlNode* t = NULL;
		GXmlGDocument* _tmp18_;
		GXmlNode* _tmp19_;
		GXmlGElement* _tmp20_;
		GeeBidirList* _tmp21_;
		GeeBidirList* _tmp22_;
		GeeBidirList* _tmp23_;
		gchar* s = NULL;
		GXmlGDocument* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		gchar** _tmp27_;
		gchar** _tmp28_;
		gchar** _tmp29_;
		gint _tmp29__length1;
		const gchar* _tmp30_;
		gchar* _tmp31_;
		gchar* _tmp32_;
		GXmlGElement* _tmp33_;
		gchar* _tmp34_;
		gchar* _tmp35_;
		gchar* _tmp36_;
		gchar* _tmp37_;
#line 115 "GElementTest.vala"
		_tmp0_ = gxml_gdocument_new ();
#line 115 "GElementTest.vala"
		doc = _tmp0_;
#line 116 "GElementTest.vala"
		_tmp2_ = doc;
#line 116 "GElementTest.vala"
		_tmp3_ = gxml_document_create_element ((GXmlDocument*) _tmp2_, "root", &_inner_error0_);
#line 116 "GElementTest.vala"
		_tmp1_ = _tmp3_;
#line 116 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 116 "GElementTest.vala"
			_g_object_unref0 (doc);
#line 1273 "GElementTest.c"
			goto __catch47_g_error;
		}
#line 116 "GElementTest.vala"
		_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_GELEMENT, GXmlGElement));
#line 116 "GElementTest.vala"
		root = _tmp4_;
#line 117 "GElementTest.vala"
		_tmp5_ = doc;
#line 117 "GElementTest.vala"
		_tmp6_ = gxml_gnode_get_children_nodes ((GXmlGNode*) _tmp5_);
#line 117 "GElementTest.vala"
		_tmp7_ = _tmp6_;
#line 117 "GElementTest.vala"
		_tmp8_ = _tmp7_;
#line 117 "GElementTest.vala"
		_tmp9_ = root;
#line 117 "GElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp8_, (GXmlNode*) _tmp9_);
#line 117 "GElementTest.vala"
		_g_object_unref0 (_tmp8_);
#line 118 "GElementTest.vala"
		_tmp11_ = doc;
#line 118 "GElementTest.vala"
		_tmp12_ = gxml_document_create_element ((GXmlDocument*) _tmp11_, "child", &_inner_error0_);
#line 118 "GElementTest.vala"
		_tmp10_ = _tmp12_;
#line 118 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 118 "GElementTest.vala"
			_g_object_unref0 (root);
#line 118 "GElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 118 "GElementTest.vala"
			_g_object_unref0 (doc);
#line 1308 "GElementTest.c"
			goto __catch47_g_error;
		}
#line 118 "GElementTest.vala"
		_tmp13_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GXML_TYPE_GELEMENT, GXmlGElement));
#line 118 "GElementTest.vala"
		n = _tmp13_;
#line 119 "GElementTest.vala"
		_tmp14_ = root;
#line 119 "GElementTest.vala"
		_tmp15_ = gxml_gnode_get_children_nodes ((GXmlGNode*) _tmp14_);
#line 119 "GElementTest.vala"
		_tmp16_ = _tmp15_;
#line 119 "GElementTest.vala"
		_tmp17_ = _tmp16_;
#line 119 "GElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp17_, (GXmlNode*) n);
#line 119 "GElementTest.vala"
		_g_object_unref0 (_tmp17_);
#line 120 "GElementTest.vala"
		_tmp18_ = doc;
#line 120 "GElementTest.vala"
		_tmp19_ = gxml_document_create_text ((GXmlDocument*) _tmp18_, "TEXT1");
#line 120 "GElementTest.vala"
		t = _tmp19_;
#line 121 "GElementTest.vala"
		_tmp20_ = root;
#line 121 "GElementTest.vala"
		_tmp21_ = gxml_gnode_get_children_nodes ((GXmlGNode*) _tmp20_);
#line 121 "GElementTest.vala"
		_tmp22_ = _tmp21_;
#line 121 "GElementTest.vala"
		_tmp23_ = _tmp22_;
#line 121 "GElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp23_, t);
#line 121 "GElementTest.vala"
		_g_object_unref0 (_tmp23_);
#line 122 "GElementTest.vala"
		_tmp24_ = doc;
#line 122 "GElementTest.vala"
		_tmp25_ = gxml_gnode_to_string ((GXmlGNode*) _tmp24_);
#line 122 "GElementTest.vala"
		_tmp26_ = _tmp25_;
#line 122 "GElementTest.vala"
		_tmp28_ = _tmp27_ = g_strsplit (_tmp26_, "\n", 0);
#line 122 "GElementTest.vala"
		_tmp29_ = _tmp28_;
#line 122 "GElementTest.vala"
		_tmp29__length1 = _vala_array_length (_tmp27_);
#line 122 "GElementTest.vala"
		_tmp30_ = _tmp29_[1];
#line 122 "GElementTest.vala"
		_tmp31_ = g_strdup (_tmp30_);
#line 122 "GElementTest.vala"
		_tmp32_ = _tmp31_;
#line 122 "GElementTest.vala"
		_tmp29_ = (_vala_array_free (_tmp29_, _tmp29__length1, (GDestroyNotify) g_free), NULL);
#line 122 "GElementTest.vala"
		_g_free0 (_tmp26_);
#line 122 "GElementTest.vala"
		s = _tmp32_;
#line 123 "GElementTest.vala"
		_tmp33_ = root;
#line 123 "GElementTest.vala"
		_tmp34_ = gxml_gnode_to_string ((GXmlGNode*) _tmp33_);
#line 123 "GElementTest.vala"
		_tmp35_ = _tmp34_;
#line 123 "GElementTest.vala"
		_tmp36_ = g_strconcat ("root=", _tmp35_, NULL);
#line 123 "GElementTest.vala"
		_tmp37_ = _tmp36_;
#line 123 "GElementTest.vala"
		g_test_message ("%s", _tmp37_);
#line 123 "GElementTest.vala"
		_g_free0 (_tmp37_);
#line 123 "GElementTest.vala"
		_g_free0 (_tmp35_);
#line 124 "GElementTest.vala"
		_vala_assert (g_strcmp0 (s, "<root><child/>TEXT1</root>") == 0, "s == \"<root><child/>TEXT1</root>\"");
#line 114 "GElementTest.vala"
		_g_free0 (s);
#line 114 "GElementTest.vala"
		_g_object_unref0 (t);
#line 114 "GElementTest.vala"
		_g_object_unref0 (n);
#line 114 "GElementTest.vala"
		_g_object_unref0 (_tmp10_);
#line 114 "GElementTest.vala"
		_g_object_unref0 (root);
#line 114 "GElementTest.vala"
		_g_object_unref0 (_tmp1_);
#line 114 "GElementTest.vala"
		_g_object_unref0 (doc);
#line 1401 "GElementTest.c"
	}
	goto __finally47;
	__catch47_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp38_;
#line 114 "GElementTest.vala"
		e = _inner_error0_;
#line 114 "GElementTest.vala"
		_inner_error0_ = NULL;
#line 126 "GElementTest.vala"
		_tmp38_ = e->message;
#line 126 "GElementTest.vala"
		g_test_message ("%s", _tmp38_);
#line 127 "GElementTest.vala"
		g_assert_not_reached ();
#line 114 "GElementTest.vala"
		_g_error_free0 (e);
#line 1420 "GElementTest.c"
	}
	__finally47:
#line 114 "GElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 114 "GElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 114 "GElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 114 "GElementTest.vala"
		return;
#line 1431 "GElementTest.c"
	}
}

static void
___lambda32__gtest_func (void)
{
#line 113 "GElementTest.vala"
	__lambda32_ ();
#line 1440 "GElementTest.c"
}

static void
__lambda33_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlNode* _tmp1_ = NULL;
		GXmlGDocument* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlGElement* root = NULL;
		GXmlGElement* _tmp4_;
		GXmlGDocument* _tmp5_;
		GeeBidirList* _tmp6_;
		GeeBidirList* _tmp7_;
		GeeBidirList* _tmp8_;
		GXmlGElement* _tmp9_;
		GXmlNode* _tmp10_ = NULL;
		GXmlGDocument* _tmp11_;
		GXmlNode* _tmp12_;
		GXmlGElement* n = NULL;
		GXmlGElement* _tmp13_;
		GXmlGElement* _tmp14_;
		GeeBidirList* _tmp15_;
		GeeBidirList* _tmp16_;
		GeeBidirList* _tmp17_;
		GXmlText* t = NULL;
		GXmlGDocument* _tmp18_;
		GXmlNode* _tmp19_;
		GXmlGElement* _tmp20_;
		GeeBidirList* _tmp21_;
		GeeBidirList* _tmp22_;
		GeeBidirList* _tmp23_;
		gchar* s = NULL;
		GXmlGDocument* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		gchar** _tmp27_;
		gchar** _tmp28_;
		gchar** _tmp29_;
		gint _tmp29__length1;
		const gchar* _tmp30_;
		gchar* _tmp31_;
		gchar* _tmp32_;
#line 132 "GElementTest.vala"
		_tmp0_ = gxml_gdocument_new ();
#line 132 "GElementTest.vala"
		doc = _tmp0_;
#line 133 "GElementTest.vala"
		_tmp2_ = doc;
#line 133 "GElementTest.vala"
		_tmp3_ = gxml_document_create_element ((GXmlDocument*) _tmp2_, "root", &_inner_error0_);
#line 133 "GElementTest.vala"
		_tmp1_ = _tmp3_;
#line 133 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 133 "GElementTest.vala"
			_g_object_unref0 (doc);
#line 1501 "GElementTest.c"
			goto __catch48_g_error;
		}
#line 133 "GElementTest.vala"
		_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_GELEMENT, GXmlGElement));
#line 133 "GElementTest.vala"
		root = _tmp4_;
#line 134 "GElementTest.vala"
		_tmp5_ = doc;
#line 134 "GElementTest.vala"
		_tmp6_ = gxml_gnode_get_children_nodes ((GXmlGNode*) _tmp5_);
#line 134 "GElementTest.vala"
		_tmp7_ = _tmp6_;
#line 134 "GElementTest.vala"
		_tmp8_ = _tmp7_;
#line 134 "GElementTest.vala"
		_tmp9_ = root;
#line 134 "GElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp8_, (GXmlNode*) _tmp9_);
#line 134 "GElementTest.vala"
		_g_object_unref0 (_tmp8_);
#line 135 "GElementTest.vala"
		_tmp11_ = doc;
#line 135 "GElementTest.vala"
		_tmp12_ = gxml_document_create_element ((GXmlDocument*) _tmp11_, "child", &_inner_error0_);
#line 135 "GElementTest.vala"
		_tmp10_ = _tmp12_;
#line 135 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 135 "GElementTest.vala"
			_g_object_unref0 (root);
#line 135 "GElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 135 "GElementTest.vala"
			_g_object_unref0 (doc);
#line 1536 "GElementTest.c"
			goto __catch48_g_error;
		}
#line 135 "GElementTest.vala"
		_tmp13_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GXML_TYPE_GELEMENT, GXmlGElement));
#line 135 "GElementTest.vala"
		n = _tmp13_;
#line 136 "GElementTest.vala"
		_tmp14_ = root;
#line 136 "GElementTest.vala"
		_tmp15_ = gxml_gnode_get_children_nodes ((GXmlGNode*) _tmp14_);
#line 136 "GElementTest.vala"
		_tmp16_ = _tmp15_;
#line 136 "GElementTest.vala"
		_tmp17_ = _tmp16_;
#line 136 "GElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp17_, (GXmlNode*) n);
#line 136 "GElementTest.vala"
		_g_object_unref0 (_tmp17_);
#line 137 "GElementTest.vala"
		_tmp18_ = doc;
#line 137 "GElementTest.vala"
		_tmp19_ = gxml_document_create_text ((GXmlDocument*) _tmp18_, "TEXT1");
#line 137 "GElementTest.vala"
		t = G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, GXML_TYPE_TEXT, GXmlText);
#line 138 "GElementTest.vala"
		_tmp20_ = root;
#line 138 "GElementTest.vala"
		_tmp21_ = gxml_gnode_get_children_nodes ((GXmlGNode*) _tmp20_);
#line 138 "GElementTest.vala"
		_tmp22_ = _tmp21_;
#line 138 "GElementTest.vala"
		_tmp23_ = _tmp22_;
#line 138 "GElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp23_, (GXmlNode*) t);
#line 138 "GElementTest.vala"
		_g_object_unref0 (_tmp23_);
#line 139 "GElementTest.vala"
		_tmp24_ = doc;
#line 139 "GElementTest.vala"
		_tmp25_ = gxml_gnode_to_string ((GXmlGNode*) _tmp24_);
#line 139 "GElementTest.vala"
		_tmp26_ = _tmp25_;
#line 139 "GElementTest.vala"
		_tmp28_ = _tmp27_ = g_strsplit (_tmp26_, "\n", 0);
#line 139 "GElementTest.vala"
		_tmp29_ = _tmp28_;
#line 139 "GElementTest.vala"
		_tmp29__length1 = _vala_array_length (_tmp27_);
#line 139 "GElementTest.vala"
		_tmp30_ = _tmp29_[1];
#line 139 "GElementTest.vala"
		_tmp31_ = g_strdup (_tmp30_);
#line 139 "GElementTest.vala"
		_tmp32_ = _tmp31_;
#line 139 "GElementTest.vala"
		_tmp29_ = (_vala_array_free (_tmp29_, _tmp29__length1, (GDestroyNotify) g_free), NULL);
#line 139 "GElementTest.vala"
		_g_free0 (_tmp26_);
#line 139 "GElementTest.vala"
		s = _tmp32_;
#line 140 "GElementTest.vala"
		_vala_assert (g_strcmp0 (s, "<root><child/>TEXT1</root>") == 0, "s == \"<root><child/>TEXT1</root>\"");
#line 131 "GElementTest.vala"
		_g_free0 (s);
#line 131 "GElementTest.vala"
		_g_object_unref0 (t);
#line 131 "GElementTest.vala"
		_g_object_unref0 (n);
#line 131 "GElementTest.vala"
		_g_object_unref0 (_tmp10_);
#line 131 "GElementTest.vala"
		_g_object_unref0 (root);
#line 131 "GElementTest.vala"
		_g_object_unref0 (_tmp1_);
#line 131 "GElementTest.vala"
		_g_object_unref0 (doc);
#line 1613 "GElementTest.c"
	}
	goto __finally48;
	__catch48_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp33_;
#line 131 "GElementTest.vala"
		e = _inner_error0_;
#line 131 "GElementTest.vala"
		_inner_error0_ = NULL;
#line 142 "GElementTest.vala"
		_tmp33_ = e->message;
#line 142 "GElementTest.vala"
		g_test_message ("%s", _tmp33_);
#line 143 "GElementTest.vala"
		g_assert_not_reached ();
#line 131 "GElementTest.vala"
		_g_error_free0 (e);
#line 1632 "GElementTest.c"
	}
	__finally48:
#line 131 "GElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 131 "GElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 131 "GElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 131 "GElementTest.vala"
		return;
#line 1643 "GElementTest.c"
	}
}

static void
___lambda33__gtest_func (void)
{
#line 130 "GElementTest.vala"
	__lambda33_ ();
#line 1652 "GElementTest.c"
}

static void
__lambda34_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlNode* _tmp1_;
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		GXmlNode* _tmp7_;
		GXmlNode* _tmp8_;
		GXmlNode* _tmp9_;
		GXmlNode* _tmp10_;
		GXmlNode* _tmp11_;
		GXmlNode* _tmp12_;
		GXmlNode* _tmp13_;
		GXmlNode* _tmp14_;
		GXmlNode* _tmp15_;
		GXmlNode* _tmp16_;
		GXmlNode* _tmp17_;
		GXmlNode* _tmp18_;
		GeeBidirList* _tmp19_;
		GeeBidirList* _tmp20_;
		GeeBidirList* _tmp21_;
		gpointer _tmp22_;
		GXmlNode* _tmp23_;
		GXmlNode* _tmp24_;
		GXmlNode* _tmp25_;
		GXmlNode* _tmp26_;
		GeeBidirList* _tmp27_;
		GeeBidirList* _tmp28_;
		GeeBidirList* _tmp29_;
		gpointer _tmp30_;
		GXmlNode* _tmp31_;
		GXmlNode* _tmp32_;
		GXmlNode* _tmp33_;
		GXmlNode* _tmp34_;
		GXmlNode* _tmp35_;
		GXmlNode* _tmp36_;
		GXmlNode* _tmp37_;
		GeeBidirList* _tmp38_;
		GeeBidirList* _tmp39_;
		GeeBidirList* _tmp40_;
		gpointer _tmp41_;
		GXmlNode* _tmp42_;
		GXmlNode* _tmp43_;
		GXmlNode* _tmp44_;
		GXmlNode* _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
#line 148 "GElementTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<root><child/></root>", 0, &_inner_error0_);
#line 148 "GElementTest.vala"
		doc = _tmp0_;
#line 148 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1716 "GElementTest.c"
			goto __catch49_g_error;
		}
#line 149 "GElementTest.vala"
		_tmp1_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 149 "GElementTest.vala"
		_tmp2_ = _tmp1_;
#line 149 "GElementTest.vala"
		_tmp3_ = _tmp2_;
#line 149 "GElementTest.vala"
		_vala_assert (_tmp3_ != NULL, "doc.root != null");
#line 149 "GElementTest.vala"
		_g_object_unref0 (_tmp3_);
#line 150 "GElementTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 150 "GElementTest.vala"
		_tmp5_ = _tmp4_;
#line 150 "GElementTest.vala"
		_tmp6_ = _tmp5_;
#line 150 "GElementTest.vala"
		_tmp7_ = gxml_node_get_parent (_tmp6_);
#line 150 "GElementTest.vala"
		_tmp8_ = _tmp7_;
#line 150 "GElementTest.vala"
		_tmp9_ = _tmp8_;
#line 150 "GElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_NODE), "doc.root.parent is GXml.Node");
#line 150 "GElementTest.vala"
		_g_object_unref0 (_tmp9_);
#line 150 "GElementTest.vala"
		_g_object_unref0 (_tmp6_);
#line 151 "GElementTest.vala"
		_tmp10_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 151 "GElementTest.vala"
		_tmp11_ = _tmp10_;
#line 151 "GElementTest.vala"
		_tmp12_ = _tmp11_;
#line 151 "GElementTest.vala"
		_tmp13_ = gxml_node_get_parent (_tmp12_);
#line 151 "GElementTest.vala"
		_tmp14_ = _tmp13_;
#line 151 "GElementTest.vala"
		_tmp15_ = _tmp14_;
#line 151 "GElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, GXML_TYPE_DOCUMENT), "doc.root.parent is GXml.Document");
#line 151 "GElementTest.vala"
		_g_object_unref0 (_tmp15_);
#line 151 "GElementTest.vala"
		_g_object_unref0 (_tmp12_);
#line 152 "GElementTest.vala"
		_tmp16_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 152 "GElementTest.vala"
		_tmp17_ = _tmp16_;
#line 152 "GElementTest.vala"
		_tmp18_ = _tmp17_;
#line 152 "GElementTest.vala"
		_tmp19_ = gxml_node_get_children_nodes (_tmp18_);
#line 152 "GElementTest.vala"
		_tmp20_ = _tmp19_;
#line 152 "GElementTest.vala"
		_tmp21_ = _tmp20_;
#line 152 "GElementTest.vala"
		_tmp22_ = gee_list_get ((GeeList*) _tmp21_, 0);
#line 152 "GElementTest.vala"
		_tmp23_ = (GXmlNode*) _tmp22_;
#line 152 "GElementTest.vala"
		_vala_assert (_tmp23_ != NULL, "doc.root.children_nodes[0] != null");
#line 152 "GElementTest.vala"
		_g_object_unref0 (_tmp23_);
#line 152 "GElementTest.vala"
		_g_object_unref0 (_tmp21_);
#line 152 "GElementTest.vala"
		_g_object_unref0 (_tmp18_);
#line 153 "GElementTest.vala"
		_tmp24_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 153 "GElementTest.vala"
		_tmp25_ = _tmp24_;
#line 153 "GElementTest.vala"
		_tmp26_ = _tmp25_;
#line 153 "GElementTest.vala"
		_tmp27_ = gxml_node_get_children_nodes (_tmp26_);
#line 153 "GElementTest.vala"
		_tmp28_ = _tmp27_;
#line 153 "GElementTest.vala"
		_tmp29_ = _tmp28_;
#line 153 "GElementTest.vala"
		_tmp30_ = gee_list_get ((GeeList*) _tmp29_, 0);
#line 153 "GElementTest.vala"
		_tmp31_ = (GXmlNode*) _tmp30_;
#line 153 "GElementTest.vala"
		_tmp32_ = gxml_node_get_parent (_tmp31_);
#line 153 "GElementTest.vala"
		_tmp33_ = _tmp32_;
#line 153 "GElementTest.vala"
		_tmp34_ = _tmp33_;
#line 153 "GElementTest.vala"
		_vala_assert (_tmp34_ != NULL, "doc.root.children_nodes[0].parent != null");
#line 153 "GElementTest.vala"
		_g_object_unref0 (_tmp34_);
#line 153 "GElementTest.vala"
		_g_object_unref0 (_tmp31_);
#line 153 "GElementTest.vala"
		_g_object_unref0 (_tmp29_);
#line 153 "GElementTest.vala"
		_g_object_unref0 (_tmp26_);
#line 154 "GElementTest.vala"
		_tmp35_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 154 "GElementTest.vala"
		_tmp36_ = _tmp35_;
#line 154 "GElementTest.vala"
		_tmp37_ = _tmp36_;
#line 154 "GElementTest.vala"
		_tmp38_ = gxml_node_get_children_nodes (_tmp37_);
#line 154 "GElementTest.vala"
		_tmp39_ = _tmp38_;
#line 154 "GElementTest.vala"
		_tmp40_ = _tmp39_;
#line 154 "GElementTest.vala"
		_tmp41_ = gee_list_get ((GeeList*) _tmp40_, 0);
#line 154 "GElementTest.vala"
		_tmp42_ = (GXmlNode*) _tmp41_;
#line 154 "GElementTest.vala"
		_tmp43_ = gxml_node_get_parent (_tmp42_);
#line 154 "GElementTest.vala"
		_tmp44_ = _tmp43_;
#line 154 "GElementTest.vala"
		_tmp45_ = _tmp44_;
#line 154 "GElementTest.vala"
		_tmp46_ = gxml_node_get_name (_tmp45_);
#line 154 "GElementTest.vala"
		_tmp47_ = _tmp46_;
#line 154 "GElementTest.vala"
		_tmp48_ = _tmp47_;
#line 154 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp48_, "root") == 0, "doc.root.children_nodes[0].parent.name == \"root\"");
#line 154 "GElementTest.vala"
		_g_free0 (_tmp48_);
#line 154 "GElementTest.vala"
		_g_object_unref0 (_tmp45_);
#line 154 "GElementTest.vala"
		_g_object_unref0 (_tmp42_);
#line 154 "GElementTest.vala"
		_g_object_unref0 (_tmp40_);
#line 154 "GElementTest.vala"
		_g_object_unref0 (_tmp37_);
#line 147 "GElementTest.vala"
		_g_object_unref0 (doc);
#line 1863 "GElementTest.c"
	}
	goto __finally49;
	__catch49_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp49_;
#line 147 "GElementTest.vala"
		e = _inner_error0_;
#line 147 "GElementTest.vala"
		_inner_error0_ = NULL;
#line 156 "GElementTest.vala"
		_tmp49_ = e->message;
#line 156 "GElementTest.vala"
		g_test_message ("%s", _tmp49_);
#line 157 "GElementTest.vala"
		g_assert_not_reached ();
#line 147 "GElementTest.vala"
		_g_error_free0 (e);
#line 1882 "GElementTest.c"
	}
	__finally49:
#line 147 "GElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 147 "GElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 147 "GElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 147 "GElementTest.vala"
		return;
#line 1893 "GElementTest.c"
	}
}

static void
___lambda34__gtest_func (void)
{
#line 146 "GElementTest.vala"
	__lambda34_ ();
#line 1902 "GElementTest.c"
}

static void
__lambda35_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_;
		GXmlDomElement* _tmp1_;
		GXmlDomElement* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlDomElement* _tmp4_;
		GXmlDomElement* _tmp5_;
		GXmlDomElement* _tmp6_;
		GXmlDomNode* _tmp7_;
		GXmlDomNode* _tmp8_;
		GXmlDomNode* _tmp9_;
		GXmlDomElement* _tmp10_;
		GXmlDomElement* _tmp11_;
		GXmlDomElement* _tmp12_;
		GXmlDomNode* _tmp13_;
		GXmlDomNode* _tmp14_;
		GXmlDomNode* _tmp15_;
		GXmlDomElement* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlDomElement* _tmp18_;
		GXmlDomNodeList* _tmp19_;
		GXmlDomNodeList* _tmp20_;
		GXmlDomNodeList* _tmp21_;
		gpointer _tmp22_;
		GXmlDomNode* _tmp23_;
		GXmlDomElement* _tmp24_;
		GXmlDomElement* _tmp25_;
		GXmlDomElement* _tmp26_;
		GXmlDomNodeList* _tmp27_;
		GXmlDomNodeList* _tmp28_;
		GXmlDomNodeList* _tmp29_;
		gpointer _tmp30_;
		GXmlDomNode* _tmp31_;
		GXmlDomNode* _tmp32_;
		GXmlDomNode* _tmp33_;
		GXmlDomNode* _tmp34_;
		GXmlDomElement* _tmp35_;
		GXmlDomElement* _tmp36_;
		GXmlDomElement* _tmp37_;
		GXmlDomNodeList* _tmp38_;
		GXmlDomNodeList* _tmp39_;
		GXmlDomNodeList* _tmp40_;
		gpointer _tmp41_;
		GXmlDomNode* _tmp42_;
		GXmlDomNode* _tmp43_;
		GXmlDomNode* _tmp44_;
		GXmlDomNode* _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		GXmlDomElement* _tmp51_;
		GXmlDomNodeList* _tmp52_;
		GXmlDomNodeList* _tmp53_;
		GXmlDomNodeList* _tmp54_;
		gpointer _tmp55_;
		GXmlDomNode* _tmp56_;
		GXmlDomElement* _tmp57_;
		GXmlDomElement* _tmp58_;
		GXmlDomElement* _tmp59_;
		GXmlDomNodeList* _tmp60_;
		GXmlDomNodeList* _tmp61_;
		GXmlDomNodeList* _tmp62_;
		gpointer _tmp63_;
		GXmlDomNode* _tmp64_;
		GXmlDomElement* _tmp65_;
		GXmlDomElement* _tmp66_;
		GXmlDomElement* _tmp67_;
		GXmlDomNodeList* _tmp68_;
		GXmlDomNodeList* _tmp69_;
		GXmlDomNodeList* _tmp70_;
		gpointer _tmp71_;
		GXmlDomNode* _tmp72_;
		GXmlDomElement* _tmp73_;
		GXmlDomElement* _tmp74_;
		GXmlDomElement* _tmp75_;
		GXmlDomNodeList* _tmp76_;
		GXmlDomNodeList* _tmp77_;
		GXmlDomNodeList* _tmp78_;
		gpointer _tmp79_;
		GXmlDomNode* _tmp80_;
		gchar* _tmp81_;
		gchar* _tmp82_;
		gchar* _tmp83_;
		GXmlDomElement* _tmp84_;
		GXmlDomElement* _tmp85_;
		GXmlDomElement* _tmp86_;
		GXmlDomNodeList* _tmp87_;
		GXmlDomNodeList* _tmp88_;
		GXmlDomNodeList* _tmp89_;
		gpointer _tmp90_;
		GXmlDomNode* _tmp91_;
		GXmlDomElement* _tmp92_;
		GXmlDomElement* _tmp93_;
		GXmlDomElement* _tmp94_;
		GXmlDomElement* _tmp95_;
		GXmlDomElement* _tmp96_;
		GXmlDomElement* _tmp97_;
		GXmlDomElement* _tmp98_;
		GXmlDomElement* _tmp99_;
		GXmlDomNodeList* _tmp100_;
		GXmlDomNodeList* _tmp101_;
		GXmlDomNodeList* _tmp102_;
		gpointer _tmp103_;
		GXmlDomNode* _tmp104_;
		GXmlDomElement* _tmp105_;
		GXmlDomElement* _tmp106_;
		GXmlDomElement* _tmp107_;
		GXmlDomElement* _tmp108_;
		GXmlDomElement* _tmp109_;
		GXmlDomElement* _tmp110_;
		GXmlDomElement* _tmp111_;
		GXmlDomElement* _tmp112_;
		GXmlDomNodeList* _tmp113_;
		GXmlDomNodeList* _tmp114_;
		GXmlDomNodeList* _tmp115_;
		gpointer _tmp116_;
		GXmlDomNode* _tmp117_;
		GXmlDomElement* _tmp118_;
		GXmlDomElement* _tmp119_;
		GXmlDomElement* _tmp120_;
		GXmlDomElement* _tmp121_;
		GXmlDomElement* _tmp122_;
		gchar* _tmp123_;
		gchar* _tmp124_;
		gchar* _tmp125_;
		GXmlDomElement* _tmp126_;
		GXmlDomElement* _tmp127_;
		GXmlDomElement* _tmp128_;
		GXmlDomNodeList* _tmp129_;
		GXmlDomNodeList* _tmp130_;
		GXmlDomNodeList* _tmp131_;
		gpointer _tmp132_;
		GXmlDomNode* _tmp133_;
		GXmlDomElement* _tmp134_;
		GXmlDomElement* _tmp135_;
		GXmlDomElement* _tmp136_;
		GXmlDomNodeList* _tmp137_;
		GXmlDomNodeList* _tmp138_;
		GXmlDomNodeList* _tmp139_;
		gpointer _tmp140_;
		GXmlDomNode* _tmp141_;
		GXmlDomNode* _tmp142_;
		GXmlDomNode* _tmp143_;
		GXmlDomNode* _tmp144_;
		GXmlDomElement* _tmp145_;
		GXmlDomElement* _tmp146_;
		GXmlDomElement* _tmp147_;
		GXmlDomNodeList* _tmp148_;
		GXmlDomNodeList* _tmp149_;
		GXmlDomNodeList* _tmp150_;
		gpointer _tmp151_;
		GXmlDomNode* _tmp152_;
		GXmlDomNode* _tmp153_;
		GXmlDomNode* _tmp154_;
		GXmlDomNode* _tmp155_;
		gchar* _tmp156_;
		gchar* _tmp157_;
		gchar* _tmp158_;
		GXmlDomElement* _tmp159_;
		GXmlDomElement* _tmp160_;
		GXmlDomElement* _tmp161_;
		GXmlDomNodeList* _tmp162_;
		GXmlDomNodeList* _tmp163_;
		GXmlDomNodeList* _tmp164_;
		gpointer _tmp165_;
		GXmlDomNode* _tmp166_;
		GXmlDomElement* _tmp167_;
		GXmlDomElement* _tmp168_;
		GXmlDomElement* _tmp169_;
		GXmlDomNodeList* _tmp170_;
		GXmlDomNodeList* _tmp171_;
		GXmlDomNodeList* _tmp172_;
		gpointer _tmp173_;
		GXmlDomNode* _tmp174_;
		GXmlDomElement* _tmp175_;
		GXmlDomElement* _tmp176_;
		GXmlDomElement* _tmp177_;
		GXmlDomNodeList* _tmp178_;
		GXmlDomNodeList* _tmp179_;
		GXmlDomNodeList* _tmp180_;
		gpointer _tmp181_;
		GXmlDomNode* _tmp182_;
		GXmlDomElement* _tmp183_;
		GXmlDomElement* _tmp184_;
		GXmlDomElement* _tmp185_;
		GXmlDomNodeList* _tmp186_;
		GXmlDomNodeList* _tmp187_;
		GXmlDomNodeList* _tmp188_;
		gpointer _tmp189_;
		GXmlDomNode* _tmp190_;
		gchar* _tmp191_;
		gchar* _tmp192_;
		gchar* _tmp193_;
		GXmlDomElement* _tmp194_;
		GXmlDomElement* _tmp195_;
		GXmlDomElement* _tmp196_;
		GXmlDomNodeList* _tmp197_;
		GXmlDomNodeList* _tmp198_;
		GXmlDomNodeList* _tmp199_;
		gpointer _tmp200_;
		GXmlDomNode* _tmp201_;
		GXmlDomElement* _tmp202_;
		GXmlDomElement* _tmp203_;
		GXmlDomElement* _tmp204_;
		GXmlDomElement* _tmp205_;
		GXmlDomElement* _tmp206_;
		GXmlDomElement* _tmp207_;
		GXmlDomElement* _tmp208_;
		GXmlDomElement* _tmp209_;
		GXmlDomNodeList* _tmp210_;
		GXmlDomNodeList* _tmp211_;
		GXmlDomNodeList* _tmp212_;
		gpointer _tmp213_;
		GXmlDomNode* _tmp214_;
		GXmlDomElement* _tmp215_;
		GXmlDomElement* _tmp216_;
		GXmlDomElement* _tmp217_;
		GXmlDomElement* _tmp218_;
		GXmlDomElement* _tmp219_;
		GXmlDomElement* _tmp220_;
		GXmlDomElement* _tmp221_;
		GXmlDomElement* _tmp222_;
		GXmlDomNodeList* _tmp223_;
		GXmlDomNodeList* _tmp224_;
		GXmlDomNodeList* _tmp225_;
		gpointer _tmp226_;
		GXmlDomNode* _tmp227_;
		GXmlDomElement* _tmp228_;
		GXmlDomElement* _tmp229_;
		GXmlDomElement* _tmp230_;
		GXmlDomElement* _tmp231_;
		GXmlDomElement* _tmp232_;
		gchar* _tmp233_;
		gchar* _tmp234_;
		gchar* _tmp235_;
#line 162 "GElementTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<root> <child/> <child/></root>", 0, &_inner_error0_);
#line 162 "GElementTest.vala"
		doc = _tmp0_;
#line 162 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 2153 "GElementTest.c"
			goto __catch50_g_error;
		}
#line 163 "GElementTest.vala"
		_tmp1_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 163 "GElementTest.vala"
		_tmp2_ = _tmp1_;
#line 163 "GElementTest.vala"
		_tmp3_ = _tmp2_;
#line 163 "GElementTest.vala"
		_vala_assert (_tmp3_ != NULL, "doc.document_element != null");
#line 163 "GElementTest.vala"
		_g_object_unref0 (_tmp3_);
#line 164 "GElementTest.vala"
		_tmp4_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 164 "GElementTest.vala"
		_tmp5_ = _tmp4_;
#line 164 "GElementTest.vala"
		_tmp6_ = _tmp5_;
#line 164 "GElementTest.vala"
		_tmp7_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp6_);
#line 164 "GElementTest.vala"
		_tmp8_ = _tmp7_;
#line 164 "GElementTest.vala"
		_tmp9_ = _tmp8_;
#line 164 "GElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_DOM_NODE), "doc.document_element.parent_node is GXml.DomNode");
#line 164 "GElementTest.vala"
		_g_object_unref0 (_tmp9_);
#line 164 "GElementTest.vala"
		_g_object_unref0 (_tmp6_);
#line 165 "GElementTest.vala"
		_tmp10_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 165 "GElementTest.vala"
		_tmp11_ = _tmp10_;
#line 165 "GElementTest.vala"
		_tmp12_ = _tmp11_;
#line 165 "GElementTest.vala"
		_tmp13_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp12_);
#line 165 "GElementTest.vala"
		_tmp14_ = _tmp13_;
#line 165 "GElementTest.vala"
		_tmp15_ = _tmp14_;
#line 165 "GElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, GXML_TYPE_DOM_DOCUMENT), "doc.document_element.parent_node is GXml.DomDocument");
#line 165 "GElementTest.vala"
		_g_object_unref0 (_tmp15_);
#line 165 "GElementTest.vala"
		_g_object_unref0 (_tmp12_);
#line 166 "GElementTest.vala"
		_tmp16_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 166 "GElementTest.vala"
		_tmp17_ = _tmp16_;
#line 166 "GElementTest.vala"
		_tmp18_ = _tmp17_;
#line 166 "GElementTest.vala"
		_tmp19_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp18_);
#line 166 "GElementTest.vala"
		_tmp20_ = _tmp19_;
#line 166 "GElementTest.vala"
		_tmp21_ = _tmp20_;
#line 166 "GElementTest.vala"
		_tmp22_ = gee_list_get ((GeeList*) _tmp21_, 0);
#line 166 "GElementTest.vala"
		_tmp23_ = (GXmlDomNode*) _tmp22_;
#line 166 "GElementTest.vala"
		_vala_assert (_tmp23_ != NULL, "doc.document_element.child_nodes[0] != null");
#line 166 "GElementTest.vala"
		_g_object_unref0 (_tmp23_);
#line 166 "GElementTest.vala"
		_g_object_unref0 (_tmp21_);
#line 166 "GElementTest.vala"
		_g_object_unref0 (_tmp18_);
#line 167 "GElementTest.vala"
		_tmp24_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 167 "GElementTest.vala"
		_tmp25_ = _tmp24_;
#line 167 "GElementTest.vala"
		_tmp26_ = _tmp25_;
#line 167 "GElementTest.vala"
		_tmp27_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp26_);
#line 167 "GElementTest.vala"
		_tmp28_ = _tmp27_;
#line 167 "GElementTest.vala"
		_tmp29_ = _tmp28_;
#line 167 "GElementTest.vala"
		_tmp30_ = gee_list_get ((GeeList*) _tmp29_, 0);
#line 167 "GElementTest.vala"
		_tmp31_ = (GXmlDomNode*) _tmp30_;
#line 167 "GElementTest.vala"
		_tmp32_ = gxml_dom_node_get_parent_node (_tmp31_);
#line 167 "GElementTest.vala"
		_tmp33_ = _tmp32_;
#line 167 "GElementTest.vala"
		_tmp34_ = _tmp33_;
#line 167 "GElementTest.vala"
		_vala_assert (_tmp34_ != NULL, "doc.document_element.child_nodes[0].parent_node != null");
#line 167 "GElementTest.vala"
		_g_object_unref0 (_tmp34_);
#line 167 "GElementTest.vala"
		_g_object_unref0 (_tmp31_);
#line 167 "GElementTest.vala"
		_g_object_unref0 (_tmp29_);
#line 167 "GElementTest.vala"
		_g_object_unref0 (_tmp26_);
#line 168 "GElementTest.vala"
		_tmp35_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 168 "GElementTest.vala"
		_tmp36_ = _tmp35_;
#line 168 "GElementTest.vala"
		_tmp37_ = _tmp36_;
#line 168 "GElementTest.vala"
		_tmp38_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp37_);
#line 168 "GElementTest.vala"
		_tmp39_ = _tmp38_;
#line 168 "GElementTest.vala"
		_tmp40_ = _tmp39_;
#line 168 "GElementTest.vala"
		_tmp41_ = gee_list_get ((GeeList*) _tmp40_, 0);
#line 168 "GElementTest.vala"
		_tmp42_ = (GXmlDomNode*) _tmp41_;
#line 168 "GElementTest.vala"
		_tmp43_ = gxml_dom_node_get_parent_node (_tmp42_);
#line 168 "GElementTest.vala"
		_tmp44_ = _tmp43_;
#line 168 "GElementTest.vala"
		_tmp45_ = _tmp44_;
#line 168 "GElementTest.vala"
		_tmp46_ = gxml_dom_node_get_node_name (_tmp45_);
#line 168 "GElementTest.vala"
		_tmp47_ = _tmp46_;
#line 168 "GElementTest.vala"
		_tmp48_ = _tmp47_;
#line 168 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp48_, "root") == 0, "doc.document_element.child_nodes[0].parent_node.node_name == \"root\"");
#line 168 "GElementTest.vala"
		_g_free0 (_tmp48_);
#line 168 "GElementTest.vala"
		_g_object_unref0 (_tmp45_);
#line 168 "GElementTest.vala"
		_g_object_unref0 (_tmp42_);
#line 168 "GElementTest.vala"
		_g_object_unref0 (_tmp40_);
#line 168 "GElementTest.vala"
		_g_object_unref0 (_tmp37_);
#line 169 "GElementTest.vala"
		_tmp49_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 169 "GElementTest.vala"
		_tmp50_ = _tmp49_;
#line 169 "GElementTest.vala"
		_tmp51_ = _tmp50_;
#line 169 "GElementTest.vala"
		_tmp52_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp51_);
#line 169 "GElementTest.vala"
		_tmp53_ = _tmp52_;
#line 169 "GElementTest.vala"
		_tmp54_ = _tmp53_;
#line 169 "GElementTest.vala"
		_tmp55_ = gee_list_get ((GeeList*) _tmp54_, 0);
#line 169 "GElementTest.vala"
		_tmp56_ = (GXmlDomNode*) _tmp55_;
#line 169 "GElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp56_, GXML_TYPE_DOM_TEXT), "doc.document_element.child_nodes[0] is DomText");
#line 169 "GElementTest.vala"
		_g_object_unref0 (_tmp56_);
#line 169 "GElementTest.vala"
		_g_object_unref0 (_tmp54_);
#line 169 "GElementTest.vala"
		_g_object_unref0 (_tmp51_);
#line 170 "GElementTest.vala"
		_tmp57_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 170 "GElementTest.vala"
		_tmp58_ = _tmp57_;
#line 170 "GElementTest.vala"
		_tmp59_ = _tmp58_;
#line 170 "GElementTest.vala"
		_tmp60_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp59_);
#line 170 "GElementTest.vala"
		_tmp61_ = _tmp60_;
#line 170 "GElementTest.vala"
		_tmp62_ = _tmp61_;
#line 170 "GElementTest.vala"
		_tmp63_ = gee_list_get ((GeeList*) _tmp62_, 1);
#line 170 "GElementTest.vala"
		_tmp64_ = (GXmlDomNode*) _tmp63_;
#line 170 "GElementTest.vala"
		_vala_assert (_tmp64_ != NULL, "doc.document_element.child_nodes[1] != null");
#line 170 "GElementTest.vala"
		_g_object_unref0 (_tmp64_);
#line 170 "GElementTest.vala"
		_g_object_unref0 (_tmp62_);
#line 170 "GElementTest.vala"
		_g_object_unref0 (_tmp59_);
#line 171 "GElementTest.vala"
		_tmp65_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 171 "GElementTest.vala"
		_tmp66_ = _tmp65_;
#line 171 "GElementTest.vala"
		_tmp67_ = _tmp66_;
#line 171 "GElementTest.vala"
		_tmp68_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp67_);
#line 171 "GElementTest.vala"
		_tmp69_ = _tmp68_;
#line 171 "GElementTest.vala"
		_tmp70_ = _tmp69_;
#line 171 "GElementTest.vala"
		_tmp71_ = gee_list_get ((GeeList*) _tmp70_, 1);
#line 171 "GElementTest.vala"
		_tmp72_ = (GXmlDomNode*) _tmp71_;
#line 171 "GElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp72_, GXML_TYPE_DOM_ELEMENT), "doc.document_element.child_nodes[1] is DomElement");
#line 171 "GElementTest.vala"
		_g_object_unref0 (_tmp72_);
#line 171 "GElementTest.vala"
		_g_object_unref0 (_tmp70_);
#line 171 "GElementTest.vala"
		_g_object_unref0 (_tmp67_);
#line 172 "GElementTest.vala"
		_tmp73_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 172 "GElementTest.vala"
		_tmp74_ = _tmp73_;
#line 172 "GElementTest.vala"
		_tmp75_ = _tmp74_;
#line 172 "GElementTest.vala"
		_tmp76_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp75_);
#line 172 "GElementTest.vala"
		_tmp77_ = _tmp76_;
#line 172 "GElementTest.vala"
		_tmp78_ = _tmp77_;
#line 172 "GElementTest.vala"
		_tmp79_ = gee_list_get ((GeeList*) _tmp78_, 1);
#line 172 "GElementTest.vala"
		_tmp80_ = (GXmlDomNode*) _tmp79_;
#line 172 "GElementTest.vala"
		_tmp81_ = gxml_dom_node_get_node_name (_tmp80_);
#line 172 "GElementTest.vala"
		_tmp82_ = _tmp81_;
#line 172 "GElementTest.vala"
		_tmp83_ = _tmp82_;
#line 172 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp83_, "child") == 0, "doc.document_element.child_nodes[1].node_name == \"child\"");
#line 172 "GElementTest.vala"
		_g_free0 (_tmp83_);
#line 172 "GElementTest.vala"
		_g_object_unref0 (_tmp80_);
#line 172 "GElementTest.vala"
		_g_object_unref0 (_tmp78_);
#line 172 "GElementTest.vala"
		_g_object_unref0 (_tmp75_);
#line 173 "GElementTest.vala"
		_tmp84_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 173 "GElementTest.vala"
		_tmp85_ = _tmp84_;
#line 173 "GElementTest.vala"
		_tmp86_ = _tmp85_;
#line 173 "GElementTest.vala"
		_tmp87_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp86_);
#line 173 "GElementTest.vala"
		_tmp88_ = _tmp87_;
#line 173 "GElementTest.vala"
		_tmp89_ = _tmp88_;
#line 173 "GElementTest.vala"
		_tmp90_ = gee_list_get ((GeeList*) _tmp89_, 1);
#line 173 "GElementTest.vala"
		_tmp91_ = (GXmlDomNode*) _tmp90_;
#line 173 "GElementTest.vala"
		_tmp92_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp91_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp91_) : NULL;
#line 173 "GElementTest.vala"
		if (_tmp92_ == NULL) {
#line 173 "GElementTest.vala"
			_g_object_unref0 (_tmp91_);
#line 2424 "GElementTest.c"
		}
#line 173 "GElementTest.vala"
		_tmp93_ = _tmp92_;
#line 173 "GElementTest.vala"
		_tmp94_ = gxml_dom_non_document_type_child_node_get_next_element_sibling ((GXmlDomNonDocumentTypeChildNode*) _tmp93_);
#line 173 "GElementTest.vala"
		_tmp95_ = _tmp94_;
#line 173 "GElementTest.vala"
		_tmp96_ = _tmp95_;
#line 173 "GElementTest.vala"
		_vala_assert (_tmp96_ != NULL, "(doc.document_element.child_nodes[1] as DomElement).next_element_sibling != null");
#line 173 "GElementTest.vala"
		_g_object_unref0 (_tmp96_);
#line 173 "GElementTest.vala"
		_g_object_unref0 (_tmp93_);
#line 173 "GElementTest.vala"
		_g_object_unref0 (_tmp89_);
#line 173 "GElementTest.vala"
		_g_object_unref0 (_tmp86_);
#line 174 "GElementTest.vala"
		_tmp97_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 174 "GElementTest.vala"
		_tmp98_ = _tmp97_;
#line 174 "GElementTest.vala"
		_tmp99_ = _tmp98_;
#line 174 "GElementTest.vala"
		_tmp100_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp99_);
#line 174 "GElementTest.vala"
		_tmp101_ = _tmp100_;
#line 174 "GElementTest.vala"
		_tmp102_ = _tmp101_;
#line 174 "GElementTest.vala"
		_tmp103_ = gee_list_get ((GeeList*) _tmp102_, 1);
#line 174 "GElementTest.vala"
		_tmp104_ = (GXmlDomNode*) _tmp103_;
#line 174 "GElementTest.vala"
		_tmp105_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp104_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp104_) : NULL;
#line 174 "GElementTest.vala"
		if (_tmp105_ == NULL) {
#line 174 "GElementTest.vala"
			_g_object_unref0 (_tmp104_);
#line 2466 "GElementTest.c"
		}
#line 174 "GElementTest.vala"
		_tmp106_ = _tmp105_;
#line 174 "GElementTest.vala"
		_tmp107_ = gxml_dom_non_document_type_child_node_get_next_element_sibling ((GXmlDomNonDocumentTypeChildNode*) _tmp106_);
#line 174 "GElementTest.vala"
		_tmp108_ = _tmp107_;
#line 174 "GElementTest.vala"
		_tmp109_ = _tmp108_;
#line 174 "GElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp109_, GXML_TYPE_DOM_ELEMENT), "(doc.document_element.child_nodes[1] as DomElement).next_element_sibling is DomElement");
#line 174 "GElementTest.vala"
		_g_object_unref0 (_tmp109_);
#line 174 "GElementTest.vala"
		_g_object_unref0 (_tmp106_);
#line 174 "GElementTest.vala"
		_g_object_unref0 (_tmp102_);
#line 174 "GElementTest.vala"
		_g_object_unref0 (_tmp99_);
#line 175 "GElementTest.vala"
		_tmp110_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 175 "GElementTest.vala"
		_tmp111_ = _tmp110_;
#line 175 "GElementTest.vala"
		_tmp112_ = _tmp111_;
#line 175 "GElementTest.vala"
		_tmp113_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp112_);
#line 175 "GElementTest.vala"
		_tmp114_ = _tmp113_;
#line 175 "GElementTest.vala"
		_tmp115_ = _tmp114_;
#line 175 "GElementTest.vala"
		_tmp116_ = gee_list_get ((GeeList*) _tmp115_, 1);
#line 175 "GElementTest.vala"
		_tmp117_ = (GXmlDomNode*) _tmp116_;
#line 175 "GElementTest.vala"
		_tmp118_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp117_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp117_) : NULL;
#line 175 "GElementTest.vala"
		if (_tmp118_ == NULL) {
#line 175 "GElementTest.vala"
			_g_object_unref0 (_tmp117_);
#line 2508 "GElementTest.c"
		}
#line 175 "GElementTest.vala"
		_tmp119_ = _tmp118_;
#line 175 "GElementTest.vala"
		_tmp120_ = gxml_dom_non_document_type_child_node_get_next_element_sibling ((GXmlDomNonDocumentTypeChildNode*) _tmp119_);
#line 175 "GElementTest.vala"
		_tmp121_ = _tmp120_;
#line 175 "GElementTest.vala"
		_tmp122_ = _tmp121_;
#line 175 "GElementTest.vala"
		_tmp123_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp122_);
#line 175 "GElementTest.vala"
		_tmp124_ = _tmp123_;
#line 175 "GElementTest.vala"
		_tmp125_ = _tmp124_;
#line 175 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp125_, "child") == 0, "(doc.document_element.child_nodes[1] as DomElement).next_element_sibling.node_name == \"child\"");
#line 175 "GElementTest.vala"
		_g_free0 (_tmp125_);
#line 175 "GElementTest.vala"
		_g_object_unref0 (_tmp122_);
#line 175 "GElementTest.vala"
		_g_object_unref0 (_tmp119_);
#line 175 "GElementTest.vala"
		_g_object_unref0 (_tmp115_);
#line 175 "GElementTest.vala"
		_g_object_unref0 (_tmp112_);
#line 176 "GElementTest.vala"
		_tmp126_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 176 "GElementTest.vala"
		_tmp127_ = _tmp126_;
#line 176 "GElementTest.vala"
		_tmp128_ = _tmp127_;
#line 176 "GElementTest.vala"
		_tmp129_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp128_);
#line 176 "GElementTest.vala"
		_tmp130_ = _tmp129_;
#line 176 "GElementTest.vala"
		_tmp131_ = _tmp130_;
#line 176 "GElementTest.vala"
		_tmp132_ = gee_list_get ((GeeList*) _tmp131_, 2);
#line 176 "GElementTest.vala"
		_tmp133_ = (GXmlDomNode*) _tmp132_;
#line 176 "GElementTest.vala"
		_vala_assert (_tmp133_ != NULL, "doc.document_element.child_nodes[2] != null");
#line 176 "GElementTest.vala"
		_g_object_unref0 (_tmp133_);
#line 176 "GElementTest.vala"
		_g_object_unref0 (_tmp131_);
#line 176 "GElementTest.vala"
		_g_object_unref0 (_tmp128_);
#line 177 "GElementTest.vala"
		_tmp134_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 177 "GElementTest.vala"
		_tmp135_ = _tmp134_;
#line 177 "GElementTest.vala"
		_tmp136_ = _tmp135_;
#line 177 "GElementTest.vala"
		_tmp137_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp136_);
#line 177 "GElementTest.vala"
		_tmp138_ = _tmp137_;
#line 177 "GElementTest.vala"
		_tmp139_ = _tmp138_;
#line 177 "GElementTest.vala"
		_tmp140_ = gee_list_get ((GeeList*) _tmp139_, 2);
#line 177 "GElementTest.vala"
		_tmp141_ = (GXmlDomNode*) _tmp140_;
#line 177 "GElementTest.vala"
		_tmp142_ = gxml_dom_node_get_parent_node (_tmp141_);
#line 177 "GElementTest.vala"
		_tmp143_ = _tmp142_;
#line 177 "GElementTest.vala"
		_tmp144_ = _tmp143_;
#line 177 "GElementTest.vala"
		_vala_assert (_tmp144_ != NULL, "doc.document_element.child_nodes[2].parent_node != null");
#line 177 "GElementTest.vala"
		_g_object_unref0 (_tmp144_);
#line 177 "GElementTest.vala"
		_g_object_unref0 (_tmp141_);
#line 177 "GElementTest.vala"
		_g_object_unref0 (_tmp139_);
#line 177 "GElementTest.vala"
		_g_object_unref0 (_tmp136_);
#line 178 "GElementTest.vala"
		_tmp145_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 178 "GElementTest.vala"
		_tmp146_ = _tmp145_;
#line 178 "GElementTest.vala"
		_tmp147_ = _tmp146_;
#line 178 "GElementTest.vala"
		_tmp148_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp147_);
#line 178 "GElementTest.vala"
		_tmp149_ = _tmp148_;
#line 178 "GElementTest.vala"
		_tmp150_ = _tmp149_;
#line 178 "GElementTest.vala"
		_tmp151_ = gee_list_get ((GeeList*) _tmp150_, 2);
#line 178 "GElementTest.vala"
		_tmp152_ = (GXmlDomNode*) _tmp151_;
#line 178 "GElementTest.vala"
		_tmp153_ = gxml_dom_node_get_parent_node (_tmp152_);
#line 178 "GElementTest.vala"
		_tmp154_ = _tmp153_;
#line 178 "GElementTest.vala"
		_tmp155_ = _tmp154_;
#line 178 "GElementTest.vala"
		_tmp156_ = gxml_dom_node_get_node_name (_tmp155_);
#line 178 "GElementTest.vala"
		_tmp157_ = _tmp156_;
#line 178 "GElementTest.vala"
		_tmp158_ = _tmp157_;
#line 178 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp158_, "root") == 0, "doc.document_element.child_nodes[2].parent_node.node_name == \"root\"");
#line 178 "GElementTest.vala"
		_g_free0 (_tmp158_);
#line 178 "GElementTest.vala"
		_g_object_unref0 (_tmp155_);
#line 178 "GElementTest.vala"
		_g_object_unref0 (_tmp152_);
#line 178 "GElementTest.vala"
		_g_object_unref0 (_tmp150_);
#line 178 "GElementTest.vala"
		_g_object_unref0 (_tmp147_);
#line 179 "GElementTest.vala"
		_tmp159_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 179 "GElementTest.vala"
		_tmp160_ = _tmp159_;
#line 179 "GElementTest.vala"
		_tmp161_ = _tmp160_;
#line 179 "GElementTest.vala"
		_tmp162_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp161_);
#line 179 "GElementTest.vala"
		_tmp163_ = _tmp162_;
#line 179 "GElementTest.vala"
		_tmp164_ = _tmp163_;
#line 179 "GElementTest.vala"
		_tmp165_ = gee_list_get ((GeeList*) _tmp164_, 2);
#line 179 "GElementTest.vala"
		_tmp166_ = (GXmlDomNode*) _tmp165_;
#line 179 "GElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp166_, GXML_TYPE_DOM_TEXT), "doc.document_element.child_nodes[2] is DomText");
#line 179 "GElementTest.vala"
		_g_object_unref0 (_tmp166_);
#line 179 "GElementTest.vala"
		_g_object_unref0 (_tmp164_);
#line 179 "GElementTest.vala"
		_g_object_unref0 (_tmp161_);
#line 180 "GElementTest.vala"
		_tmp167_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 180 "GElementTest.vala"
		_tmp168_ = _tmp167_;
#line 180 "GElementTest.vala"
		_tmp169_ = _tmp168_;
#line 180 "GElementTest.vala"
		_tmp170_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp169_);
#line 180 "GElementTest.vala"
		_tmp171_ = _tmp170_;
#line 180 "GElementTest.vala"
		_tmp172_ = _tmp171_;
#line 180 "GElementTest.vala"
		_tmp173_ = gee_list_get ((GeeList*) _tmp172_, 3);
#line 180 "GElementTest.vala"
		_tmp174_ = (GXmlDomNode*) _tmp173_;
#line 180 "GElementTest.vala"
		_vala_assert (_tmp174_ != NULL, "doc.document_element.child_nodes[3] != null");
#line 180 "GElementTest.vala"
		_g_object_unref0 (_tmp174_);
#line 180 "GElementTest.vala"
		_g_object_unref0 (_tmp172_);
#line 180 "GElementTest.vala"
		_g_object_unref0 (_tmp169_);
#line 181 "GElementTest.vala"
		_tmp175_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 181 "GElementTest.vala"
		_tmp176_ = _tmp175_;
#line 181 "GElementTest.vala"
		_tmp177_ = _tmp176_;
#line 181 "GElementTest.vala"
		_tmp178_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp177_);
#line 181 "GElementTest.vala"
		_tmp179_ = _tmp178_;
#line 181 "GElementTest.vala"
		_tmp180_ = _tmp179_;
#line 181 "GElementTest.vala"
		_tmp181_ = gee_list_get ((GeeList*) _tmp180_, 3);
#line 181 "GElementTest.vala"
		_tmp182_ = (GXmlDomNode*) _tmp181_;
#line 181 "GElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp182_, GXML_TYPE_DOM_ELEMENT), "doc.document_element.child_nodes[3] is DomElement");
#line 181 "GElementTest.vala"
		_g_object_unref0 (_tmp182_);
#line 181 "GElementTest.vala"
		_g_object_unref0 (_tmp180_);
#line 181 "GElementTest.vala"
		_g_object_unref0 (_tmp177_);
#line 182 "GElementTest.vala"
		_tmp183_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 182 "GElementTest.vala"
		_tmp184_ = _tmp183_;
#line 182 "GElementTest.vala"
		_tmp185_ = _tmp184_;
#line 182 "GElementTest.vala"
		_tmp186_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp185_);
#line 182 "GElementTest.vala"
		_tmp187_ = _tmp186_;
#line 182 "GElementTest.vala"
		_tmp188_ = _tmp187_;
#line 182 "GElementTest.vala"
		_tmp189_ = gee_list_get ((GeeList*) _tmp188_, 3);
#line 182 "GElementTest.vala"
		_tmp190_ = (GXmlDomNode*) _tmp189_;
#line 182 "GElementTest.vala"
		_tmp191_ = gxml_dom_node_get_node_name (_tmp190_);
#line 182 "GElementTest.vala"
		_tmp192_ = _tmp191_;
#line 182 "GElementTest.vala"
		_tmp193_ = _tmp192_;
#line 182 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp193_, "child") == 0, "doc.document_element.child_nodes[3].node_name == \"child\"");
#line 182 "GElementTest.vala"
		_g_free0 (_tmp193_);
#line 182 "GElementTest.vala"
		_g_object_unref0 (_tmp190_);
#line 182 "GElementTest.vala"
		_g_object_unref0 (_tmp188_);
#line 182 "GElementTest.vala"
		_g_object_unref0 (_tmp185_);
#line 183 "GElementTest.vala"
		_tmp194_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 183 "GElementTest.vala"
		_tmp195_ = _tmp194_;
#line 183 "GElementTest.vala"
		_tmp196_ = _tmp195_;
#line 183 "GElementTest.vala"
		_tmp197_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp196_);
#line 183 "GElementTest.vala"
		_tmp198_ = _tmp197_;
#line 183 "GElementTest.vala"
		_tmp199_ = _tmp198_;
#line 183 "GElementTest.vala"
		_tmp200_ = gee_list_get ((GeeList*) _tmp199_, 3);
#line 183 "GElementTest.vala"
		_tmp201_ = (GXmlDomNode*) _tmp200_;
#line 183 "GElementTest.vala"
		_tmp202_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp201_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp201_) : NULL;
#line 183 "GElementTest.vala"
		if (_tmp202_ == NULL) {
#line 183 "GElementTest.vala"
			_g_object_unref0 (_tmp201_);
#line 2758 "GElementTest.c"
		}
#line 183 "GElementTest.vala"
		_tmp203_ = _tmp202_;
#line 183 "GElementTest.vala"
		_tmp204_ = gxml_dom_non_document_type_child_node_get_previous_element_sibling ((GXmlDomNonDocumentTypeChildNode*) _tmp203_);
#line 183 "GElementTest.vala"
		_tmp205_ = _tmp204_;
#line 183 "GElementTest.vala"
		_tmp206_ = _tmp205_;
#line 183 "GElementTest.vala"
		_vala_assert (_tmp206_ != NULL, "(doc.document_element.child_nodes[3] as DomElement).previous_element_sibling != null");
#line 183 "GElementTest.vala"
		_g_object_unref0 (_tmp206_);
#line 183 "GElementTest.vala"
		_g_object_unref0 (_tmp203_);
#line 183 "GElementTest.vala"
		_g_object_unref0 (_tmp199_);
#line 183 "GElementTest.vala"
		_g_object_unref0 (_tmp196_);
#line 184 "GElementTest.vala"
		_tmp207_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 184 "GElementTest.vala"
		_tmp208_ = _tmp207_;
#line 184 "GElementTest.vala"
		_tmp209_ = _tmp208_;
#line 184 "GElementTest.vala"
		_tmp210_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp209_);
#line 184 "GElementTest.vala"
		_tmp211_ = _tmp210_;
#line 184 "GElementTest.vala"
		_tmp212_ = _tmp211_;
#line 184 "GElementTest.vala"
		_tmp213_ = gee_list_get ((GeeList*) _tmp212_, 3);
#line 184 "GElementTest.vala"
		_tmp214_ = (GXmlDomNode*) _tmp213_;
#line 184 "GElementTest.vala"
		_tmp215_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp214_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp214_) : NULL;
#line 184 "GElementTest.vala"
		if (_tmp215_ == NULL) {
#line 184 "GElementTest.vala"
			_g_object_unref0 (_tmp214_);
#line 2800 "GElementTest.c"
		}
#line 184 "GElementTest.vala"
		_tmp216_ = _tmp215_;
#line 184 "GElementTest.vala"
		_tmp217_ = gxml_dom_non_document_type_child_node_get_previous_element_sibling ((GXmlDomNonDocumentTypeChildNode*) _tmp216_);
#line 184 "GElementTest.vala"
		_tmp218_ = _tmp217_;
#line 184 "GElementTest.vala"
		_tmp219_ = _tmp218_;
#line 184 "GElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp219_, GXML_TYPE_DOM_ELEMENT), "(doc.document_element.child_nodes[3] as DomElement).previous_element_sibling is DomElement");
#line 184 "GElementTest.vala"
		_g_object_unref0 (_tmp219_);
#line 184 "GElementTest.vala"
		_g_object_unref0 (_tmp216_);
#line 184 "GElementTest.vala"
		_g_object_unref0 (_tmp212_);
#line 184 "GElementTest.vala"
		_g_object_unref0 (_tmp209_);
#line 185 "GElementTest.vala"
		_tmp220_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 185 "GElementTest.vala"
		_tmp221_ = _tmp220_;
#line 185 "GElementTest.vala"
		_tmp222_ = _tmp221_;
#line 185 "GElementTest.vala"
		_tmp223_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp222_);
#line 185 "GElementTest.vala"
		_tmp224_ = _tmp223_;
#line 185 "GElementTest.vala"
		_tmp225_ = _tmp224_;
#line 185 "GElementTest.vala"
		_tmp226_ = gee_list_get ((GeeList*) _tmp225_, 3);
#line 185 "GElementTest.vala"
		_tmp227_ = (GXmlDomNode*) _tmp226_;
#line 185 "GElementTest.vala"
		_tmp228_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp227_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp227_) : NULL;
#line 185 "GElementTest.vala"
		if (_tmp228_ == NULL) {
#line 185 "GElementTest.vala"
			_g_object_unref0 (_tmp227_);
#line 2842 "GElementTest.c"
		}
#line 185 "GElementTest.vala"
		_tmp229_ = _tmp228_;
#line 185 "GElementTest.vala"
		_tmp230_ = gxml_dom_non_document_type_child_node_get_previous_element_sibling ((GXmlDomNonDocumentTypeChildNode*) _tmp229_);
#line 185 "GElementTest.vala"
		_tmp231_ = _tmp230_;
#line 185 "GElementTest.vala"
		_tmp232_ = _tmp231_;
#line 185 "GElementTest.vala"
		_tmp233_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp232_);
#line 185 "GElementTest.vala"
		_tmp234_ = _tmp233_;
#line 185 "GElementTest.vala"
		_tmp235_ = _tmp234_;
#line 185 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp235_, "child") == 0, "(doc.document_element.child_nodes[3] as DomElement).previous_element_sibling.node_name == \"child\"");
#line 185 "GElementTest.vala"
		_g_free0 (_tmp235_);
#line 185 "GElementTest.vala"
		_g_object_unref0 (_tmp232_);
#line 185 "GElementTest.vala"
		_g_object_unref0 (_tmp229_);
#line 185 "GElementTest.vala"
		_g_object_unref0 (_tmp225_);
#line 185 "GElementTest.vala"
		_g_object_unref0 (_tmp222_);
#line 161 "GElementTest.vala"
		_g_object_unref0 (doc);
#line 2872 "GElementTest.c"
	}
	goto __finally50;
	__catch50_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp236_;
#line 161 "GElementTest.vala"
		e = _inner_error0_;
#line 161 "GElementTest.vala"
		_inner_error0_ = NULL;
#line 187 "GElementTest.vala"
		_tmp236_ = e->message;
#line 187 "GElementTest.vala"
		g_test_message ("%s", _tmp236_);
#line 188 "GElementTest.vala"
		g_assert_not_reached ();
#line 161 "GElementTest.vala"
		_g_error_free0 (e);
#line 2891 "GElementTest.c"
	}
	__finally50:
#line 161 "GElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 161 "GElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 161 "GElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 161 "GElementTest.vala"
		return;
#line 2902 "GElementTest.c"
	}
}

static void
___lambda35__gtest_func (void)
{
#line 160 "GElementTest.vala"
	__lambda35_ ();
#line 2911 "GElementTest.c"
}

static void
__lambda36_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlDomDocument* d = NULL;
		GXmlGDocument* _tmp0_;
		GXmlDomDocument* _tmp1_;
		GXmlDomElement* r = NULL;
		GXmlDomDocument* _tmp2_;
		GXmlDomElement* _tmp3_;
		GXmlDomDocument* _tmp4_;
		GXmlDomElement* _tmp5_;
		GXmlDomNode* _tmp6_;
		GXmlDomNode* _tmp7_;
		GXmlDomElement* c1 = NULL;
		GXmlDomDocument* _tmp8_;
		GXmlDomElement* _tmp9_;
		GXmlDomElement* _tmp10_;
		GXmlDomElement* _tmp11_;
		GXmlDomElement* _tmp12_;
		GXmlDomNode* _tmp13_;
		GXmlDomNode* _tmp14_;
		GXmlDomElement* c2 = NULL;
		GXmlDomDocument* _tmp15_;
		GXmlDomElement* _tmp16_;
		GXmlDomElement* _tmp17_;
		GXmlDomElement* _tmp18_;
		GXmlDomElement* _tmp19_;
		GXmlDomNode* _tmp20_;
		GXmlDomNode* _tmp21_;
		GXmlDomElement* c3 = NULL;
		GXmlDomDocument* _tmp22_;
		GXmlDomElement* _tmp23_;
		GXmlDomElement* _tmp24_;
		GXmlDomElement* _tmp25_;
		GXmlDomElement* _tmp26_;
		GXmlDomNode* _tmp27_;
		GXmlDomNode* _tmp28_;
		GXmlDomElement* c4 = NULL;
		GXmlDomDocument* _tmp29_;
		GXmlDomElement* _tmp30_;
		GXmlDomElement* _tmp31_;
		GXmlDomElement* _tmp32_;
		GXmlDomElement* _tmp33_;
		GXmlDomNode* _tmp34_;
		GXmlDomNode* _tmp35_;
		GXmlDomElement* c5 = NULL;
		GXmlDomDocument* _tmp36_;
		GXmlDomElement* _tmp37_;
		GXmlDomElement* _tmp38_;
		GXmlDomElement* _tmp39_;
		GXmlDomNode* _tmp40_;
		GXmlDomNode* _tmp41_;
		GXmlDomElement* n1 = NULL;
		GXmlDomElement* _tmp42_;
		GXmlDomElement* _tmp43_;
		GXmlDomElement* _tmp44_;
		GXmlDomElement* _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
		GXmlDomElement* n2 = NULL;
		GXmlDomElement* _tmp48_;
		GXmlDomElement* _tmp49_;
		GXmlDomElement* _tmp50_;
		GXmlDomElement* _tmp51_;
		gchar* _tmp52_;
		gchar* _tmp53_;
		GXmlDomElement* n3 = NULL;
		GXmlDomElement* _tmp54_;
		GXmlDomElement* _tmp55_;
		GXmlDomElement* _tmp56_;
		GXmlDomElement* _tmp57_;
		gchar* _tmp58_;
		gchar* _tmp59_;
		GXmlDomElement* n4 = NULL;
		GXmlDomElement* _tmp60_;
		GXmlDomElement* _tmp61_;
		GXmlDomElement* _tmp62_;
		GXmlDomElement* _tmp63_;
		gchar* _tmp64_;
		gchar* _tmp65_;
		GXmlDomNodeList* l1 = NULL;
		GXmlDomElement* _tmp66_;
		GXmlDomNodeList* _tmp67_;
		GXmlDomNodeList* _tmp68_;
		GXmlDomNodeList* _tmp69_;
		gint _tmp70_;
		gint _tmp71_;
		GXmlDomNodeList* _tmp72_;
		GXmlDomNode* _tmp73_;
		GXmlDomNode* _tmp74_;
		gchar* _tmp75_;
		gchar* _tmp76_;
		gchar* _tmp77_;
		GXmlDomNodeList* l2 = NULL;
		GXmlDomElement* _tmp78_;
		GXmlDomNodeList* _tmp79_;
		GXmlDomNodeList* _tmp80_;
		GXmlDomNodeList* _tmp81_;
		gint _tmp82_;
		gint _tmp83_;
		GXmlDomNodeList* _tmp84_;
		GXmlDomNode* _tmp85_;
		GXmlDomNode* _tmp86_;
		gchar* _tmp87_;
		gchar* _tmp88_;
		gchar* _tmp89_;
		GXmlDomNodeList* l3 = NULL;
		GXmlDomElement* _tmp90_;
		GXmlDomNodeList* _tmp91_;
		GXmlDomNodeList* _tmp92_;
		GXmlDomNodeList* _tmp93_;
		gint _tmp94_;
		gint _tmp95_;
		GXmlDomNodeList* _tmp96_;
		GXmlDomNode* _tmp97_;
		GXmlDomNode* _tmp98_;
		gchar* _tmp99_;
		gchar* _tmp100_;
		gchar* _tmp101_;
		GXmlDomElement* c6 = NULL;
		GXmlDomDocument* _tmp102_;
		GXmlDomElement* _tmp103_;
		GXmlDomElement* _tmp104_;
		GXmlDomElement* _tmp105_;
		GXmlDomElement* _tmp106_;
		GXmlDomNode* _tmp107_;
		GXmlDomNode* _tmp108_;
		GXmlDomElement* c7 = NULL;
		GXmlDomDocument* _tmp109_;
		GXmlDomElement* _tmp110_;
		GXmlDomElement* _tmp111_;
		GXmlDomElement* _tmp112_;
		GXmlDomElement* _tmp113_;
		GXmlDomNode* _tmp114_;
		GXmlDomNode* _tmp115_;
		GXmlDomNodeList* l4 = NULL;
		GXmlDomElement* _tmp116_;
		GXmlDomNodeList* _tmp117_;
		GXmlDomNodeList* _tmp118_;
		GXmlDomNodeList* _tmp119_;
		gint _tmp120_;
		gint _tmp121_;
		GXmlDomNodeList* _tmp122_;
		GXmlDomNode* _tmp123_;
		GXmlDomNode* _tmp124_;
		gchar* _tmp125_;
		gchar* _tmp126_;
		gchar* _tmp127_;
#line 193 "GElementTest.vala"
		_tmp0_ = gxml_gdocument_new ();
#line 193 "GElementTest.vala"
		_tmp1_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp0_) : NULL;
#line 193 "GElementTest.vala"
		if (_tmp1_ == NULL) {
#line 193 "GElementTest.vala"
			_g_object_unref0 (_tmp0_);
#line 3072 "GElementTest.c"
		}
#line 193 "GElementTest.vala"
		d = _tmp1_;
#line 194 "GElementTest.vala"
		_tmp2_ = d;
#line 194 "GElementTest.vala"
		_tmp3_ = gxml_dom_document_create_element (_tmp2_, "root", &_inner_error0_);
#line 194 "GElementTest.vala"
		r = _tmp3_;
#line 194 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 194 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3086 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 195 "GElementTest.vala"
		_tmp4_ = d;
#line 195 "GElementTest.vala"
		_tmp5_ = r;
#line 195 "GElementTest.vala"
		_tmp6_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp4_, (GXmlDomNode*) _tmp5_, &_inner_error0_);
#line 195 "GElementTest.vala"
		_tmp7_ = _tmp6_;
#line 195 "GElementTest.vala"
		_g_object_unref0 (_tmp7_);
#line 195 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 195 "GElementTest.vala"
			_g_object_unref0 (r);
#line 195 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3105 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 196 "GElementTest.vala"
		_tmp8_ = d;
#line 196 "GElementTest.vala"
		_tmp9_ = gxml_dom_document_create_element (_tmp8_, "child", &_inner_error0_);
#line 196 "GElementTest.vala"
		c1 = _tmp9_;
#line 196 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 196 "GElementTest.vala"
			_g_object_unref0 (r);
#line 196 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3120 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 197 "GElementTest.vala"
		_tmp10_ = c1;
#line 197 "GElementTest.vala"
		gxml_dom_element_set_attribute (_tmp10_, "class", "error", &_inner_error0_);
#line 197 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 197 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 197 "GElementTest.vala"
			_g_object_unref0 (r);
#line 197 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3135 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 198 "GElementTest.vala"
		_tmp11_ = r;
#line 198 "GElementTest.vala"
		_tmp12_ = c1;
#line 198 "GElementTest.vala"
		_tmp13_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp11_, (GXmlDomNode*) _tmp12_, &_inner_error0_);
#line 198 "GElementTest.vala"
		_tmp14_ = _tmp13_;
#line 198 "GElementTest.vala"
		_g_object_unref0 (_tmp14_);
#line 198 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 198 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 198 "GElementTest.vala"
			_g_object_unref0 (r);
#line 198 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3156 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 199 "GElementTest.vala"
		_tmp15_ = d;
#line 199 "GElementTest.vala"
		_tmp16_ = gxml_dom_document_create_element (_tmp15_, "child", &_inner_error0_);
#line 199 "GElementTest.vala"
		c2 = _tmp16_;
#line 199 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 199 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 199 "GElementTest.vala"
			_g_object_unref0 (r);
#line 199 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3173 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 200 "GElementTest.vala"
		_tmp17_ = c2;
#line 200 "GElementTest.vala"
		gxml_dom_element_set_attribute (_tmp17_, "class", "warning", &_inner_error0_);
#line 200 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 200 "GElementTest.vala"
			_g_object_unref0 (c2);
#line 200 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 200 "GElementTest.vala"
			_g_object_unref0 (r);
#line 200 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3190 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 201 "GElementTest.vala"
		_tmp18_ = r;
#line 201 "GElementTest.vala"
		_tmp19_ = c2;
#line 201 "GElementTest.vala"
		_tmp20_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp18_, (GXmlDomNode*) _tmp19_, &_inner_error0_);
#line 201 "GElementTest.vala"
		_tmp21_ = _tmp20_;
#line 201 "GElementTest.vala"
		_g_object_unref0 (_tmp21_);
#line 201 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 201 "GElementTest.vala"
			_g_object_unref0 (c2);
#line 201 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 201 "GElementTest.vala"
			_g_object_unref0 (r);
#line 201 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3213 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 202 "GElementTest.vala"
		_tmp22_ = d;
#line 202 "GElementTest.vala"
		_tmp23_ = gxml_dom_document_create_element (_tmp22_, "child", &_inner_error0_);
#line 202 "GElementTest.vala"
		c3 = _tmp23_;
#line 202 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 202 "GElementTest.vala"
			_g_object_unref0 (c2);
#line 202 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 202 "GElementTest.vala"
			_g_object_unref0 (r);
#line 202 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3232 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 203 "GElementTest.vala"
		_tmp24_ = c3;
#line 203 "GElementTest.vala"
		gxml_dom_element_set_attribute (_tmp24_, "class", "error warning", &_inner_error0_);
#line 203 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 203 "GElementTest.vala"
			_g_object_unref0 (c3);
#line 203 "GElementTest.vala"
			_g_object_unref0 (c2);
#line 203 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 203 "GElementTest.vala"
			_g_object_unref0 (r);
#line 203 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3251 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 204 "GElementTest.vala"
		_tmp25_ = r;
#line 204 "GElementTest.vala"
		_tmp26_ = c3;
#line 204 "GElementTest.vala"
		_tmp27_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp25_, (GXmlDomNode*) _tmp26_, &_inner_error0_);
#line 204 "GElementTest.vala"
		_tmp28_ = _tmp27_;
#line 204 "GElementTest.vala"
		_g_object_unref0 (_tmp28_);
#line 204 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 204 "GElementTest.vala"
			_g_object_unref0 (c3);
#line 204 "GElementTest.vala"
			_g_object_unref0 (c2);
#line 204 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 204 "GElementTest.vala"
			_g_object_unref0 (r);
#line 204 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3276 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 205 "GElementTest.vala"
		_tmp29_ = d;
#line 205 "GElementTest.vala"
		_tmp30_ = gxml_dom_document_create_element (_tmp29_, "child", &_inner_error0_);
#line 205 "GElementTest.vala"
		c4 = _tmp30_;
#line 205 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 205 "GElementTest.vala"
			_g_object_unref0 (c3);
#line 205 "GElementTest.vala"
			_g_object_unref0 (c2);
#line 205 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 205 "GElementTest.vala"
			_g_object_unref0 (r);
#line 205 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3297 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 206 "GElementTest.vala"
		_tmp31_ = c4;
#line 206 "GElementTest.vala"
		gxml_dom_element_set_attribute (_tmp31_, "class", "error calc", &_inner_error0_);
#line 206 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 206 "GElementTest.vala"
			_g_object_unref0 (c4);
#line 206 "GElementTest.vala"
			_g_object_unref0 (c3);
#line 206 "GElementTest.vala"
			_g_object_unref0 (c2);
#line 206 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 206 "GElementTest.vala"
			_g_object_unref0 (r);
#line 206 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3318 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 207 "GElementTest.vala"
		_tmp32_ = r;
#line 207 "GElementTest.vala"
		_tmp33_ = c4;
#line 207 "GElementTest.vala"
		_tmp34_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp32_, (GXmlDomNode*) _tmp33_, &_inner_error0_);
#line 207 "GElementTest.vala"
		_tmp35_ = _tmp34_;
#line 207 "GElementTest.vala"
		_g_object_unref0 (_tmp35_);
#line 207 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 207 "GElementTest.vala"
			_g_object_unref0 (c4);
#line 207 "GElementTest.vala"
			_g_object_unref0 (c3);
#line 207 "GElementTest.vala"
			_g_object_unref0 (c2);
#line 207 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 207 "GElementTest.vala"
			_g_object_unref0 (r);
#line 207 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3345 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 208 "GElementTest.vala"
		_tmp36_ = d;
#line 208 "GElementTest.vala"
		_tmp37_ = gxml_dom_document_create_element (_tmp36_, "child", &_inner_error0_);
#line 208 "GElementTest.vala"
		c5 = _tmp37_;
#line 208 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 208 "GElementTest.vala"
			_g_object_unref0 (c4);
#line 208 "GElementTest.vala"
			_g_object_unref0 (c3);
#line 208 "GElementTest.vala"
			_g_object_unref0 (c2);
#line 208 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 208 "GElementTest.vala"
			_g_object_unref0 (r);
#line 208 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3368 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 209 "GElementTest.vala"
		_tmp38_ = r;
#line 209 "GElementTest.vala"
		_tmp39_ = c5;
#line 209 "GElementTest.vala"
		_tmp40_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp38_, (GXmlDomNode*) _tmp39_, &_inner_error0_);
#line 209 "GElementTest.vala"
		_tmp41_ = _tmp40_;
#line 209 "GElementTest.vala"
		_g_object_unref0 (_tmp41_);
#line 209 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 209 "GElementTest.vala"
			_g_object_unref0 (c5);
#line 209 "GElementTest.vala"
			_g_object_unref0 (c4);
#line 209 "GElementTest.vala"
			_g_object_unref0 (c3);
#line 209 "GElementTest.vala"
			_g_object_unref0 (c2);
#line 209 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 209 "GElementTest.vala"
			_g_object_unref0 (r);
#line 209 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3397 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 210 "GElementTest.vala"
		_tmp42_ = r;
#line 210 "GElementTest.vala"
		_tmp43_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp42_, "child", &_inner_error0_);
#line 210 "GElementTest.vala"
		n1 = _tmp43_;
#line 210 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 210 "GElementTest.vala"
			_g_object_unref0 (c5);
#line 210 "GElementTest.vala"
			_g_object_unref0 (c4);
#line 210 "GElementTest.vala"
			_g_object_unref0 (c3);
#line 210 "GElementTest.vala"
			_g_object_unref0 (c2);
#line 210 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 210 "GElementTest.vala"
			_g_object_unref0 (r);
#line 210 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3422 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 211 "GElementTest.vala"
		_tmp44_ = n1;
#line 211 "GElementTest.vala"
		_vala_assert (_tmp44_ != NULL, "n1 != null");
#line 212 "GElementTest.vala"
		_tmp45_ = n1;
#line 212 "GElementTest.vala"
		_tmp46_ = gxml_dom_element_get_attribute (_tmp45_, "class");
#line 212 "GElementTest.vala"
		_tmp47_ = _tmp46_;
#line 212 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp47_, "error") == 0, "n1.get_attribute (\"class\") == \"error\"");
#line 212 "GElementTest.vala"
		_g_free0 (_tmp47_);
#line 213 "GElementTest.vala"
		_tmp48_ = r;
#line 213 "GElementTest.vala"
		_tmp49_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp48_, "child.warning", &_inner_error0_);
#line 213 "GElementTest.vala"
		n2 = _tmp49_;
#line 213 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 213 "GElementTest.vala"
			_g_object_unref0 (n1);
#line 213 "GElementTest.vala"
			_g_object_unref0 (c5);
#line 213 "GElementTest.vala"
			_g_object_unref0 (c4);
#line 213 "GElementTest.vala"
			_g_object_unref0 (c3);
#line 213 "GElementTest.vala"
			_g_object_unref0 (c2);
#line 213 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 213 "GElementTest.vala"
			_g_object_unref0 (r);
#line 213 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3463 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 214 "GElementTest.vala"
		_tmp50_ = n2;
#line 214 "GElementTest.vala"
		_vala_assert (_tmp50_ != NULL, "n2 != null");
#line 215 "GElementTest.vala"
		_tmp51_ = n2;
#line 215 "GElementTest.vala"
		_tmp52_ = gxml_dom_element_get_attribute (_tmp51_, "class");
#line 215 "GElementTest.vala"
		_tmp53_ = _tmp52_;
#line 215 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp53_, "warning") == 0, "n2.get_attribute (\"class\") == \"warning\"");
#line 215 "GElementTest.vala"
		_g_free0 (_tmp53_);
#line 216 "GElementTest.vala"
		_tmp54_ = r;
#line 216 "GElementTest.vala"
		_tmp55_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp54_, "child[class]", &_inner_error0_);
#line 216 "GElementTest.vala"
		n3 = _tmp55_;
#line 216 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 216 "GElementTest.vala"
			_g_object_unref0 (n2);
#line 216 "GElementTest.vala"
			_g_object_unref0 (n1);
#line 216 "GElementTest.vala"
			_g_object_unref0 (c5);
#line 216 "GElementTest.vala"
			_g_object_unref0 (c4);
#line 216 "GElementTest.vala"
			_g_object_unref0 (c3);
#line 216 "GElementTest.vala"
			_g_object_unref0 (c2);
#line 216 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 216 "GElementTest.vala"
			_g_object_unref0 (r);
#line 216 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3506 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 217 "GElementTest.vala"
		_tmp56_ = n3;
#line 217 "GElementTest.vala"
		_vala_assert (_tmp56_ != NULL, "n3 != null");
#line 218 "GElementTest.vala"
		_tmp57_ = n3;
#line 218 "GElementTest.vala"
		_tmp58_ = gxml_dom_element_get_attribute (_tmp57_, "class");
#line 218 "GElementTest.vala"
		_tmp59_ = _tmp58_;
#line 218 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp59_, "error") == 0, "n3.get_attribute (\"class\") == \"error\"");
#line 218 "GElementTest.vala"
		_g_free0 (_tmp59_);
#line 219 "GElementTest.vala"
		_tmp60_ = r;
#line 219 "GElementTest.vala"
		_tmp61_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp60_, "child[class=\"error calc\"]", &_inner_error0_);
#line 219 "GElementTest.vala"
		n4 = _tmp61_;
#line 219 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 219 "GElementTest.vala"
			_g_object_unref0 (n3);
#line 219 "GElementTest.vala"
			_g_object_unref0 (n2);
#line 219 "GElementTest.vala"
			_g_object_unref0 (n1);
#line 219 "GElementTest.vala"
			_g_object_unref0 (c5);
#line 219 "GElementTest.vala"
			_g_object_unref0 (c4);
#line 219 "GElementTest.vala"
			_g_object_unref0 (c3);
#line 219 "GElementTest.vala"
			_g_object_unref0 (c2);
#line 219 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 219 "GElementTest.vala"
			_g_object_unref0 (r);
#line 219 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3551 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 220 "GElementTest.vala"
		_tmp62_ = n4;
#line 220 "GElementTest.vala"
		_vala_assert (_tmp62_ != NULL, "n4 != null");
#line 221 "GElementTest.vala"
		_tmp63_ = n4;
#line 221 "GElementTest.vala"
		_tmp64_ = gxml_dom_element_get_attribute (_tmp63_, "class");
#line 221 "GElementTest.vala"
		_tmp65_ = _tmp64_;
#line 221 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp65_, "error calc") == 0, "n4.get_attribute (\"class\") == \"error calc\"");
#line 221 "GElementTest.vala"
		_g_free0 (_tmp65_);
#line 222 "GElementTest.vala"
		_tmp66_ = r;
#line 222 "GElementTest.vala"
		_tmp67_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp66_, "child", &_inner_error0_);
#line 222 "GElementTest.vala"
		l1 = _tmp67_;
#line 222 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 222 "GElementTest.vala"
			_g_object_unref0 (n4);
#line 222 "GElementTest.vala"
			_g_object_unref0 (n3);
#line 222 "GElementTest.vala"
			_g_object_unref0 (n2);
#line 222 "GElementTest.vala"
			_g_object_unref0 (n1);
#line 222 "GElementTest.vala"
			_g_object_unref0 (c5);
#line 222 "GElementTest.vala"
			_g_object_unref0 (c4);
#line 222 "GElementTest.vala"
			_g_object_unref0 (c3);
#line 222 "GElementTest.vala"
			_g_object_unref0 (c2);
#line 222 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 222 "GElementTest.vala"
			_g_object_unref0 (r);
#line 222 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3598 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 223 "GElementTest.vala"
		_tmp68_ = l1;
#line 223 "GElementTest.vala"
		_vala_assert (_tmp68_ != NULL, "l1 != null");
#line 224 "GElementTest.vala"
		_tmp69_ = l1;
#line 224 "GElementTest.vala"
		_tmp70_ = gxml_dom_node_list_get_length (_tmp69_);
#line 224 "GElementTest.vala"
		_tmp71_ = _tmp70_;
#line 224 "GElementTest.vala"
		_vala_assert (_tmp71_ == 5, "l1.length == 5");
#line 225 "GElementTest.vala"
		_tmp72_ = l1;
#line 225 "GElementTest.vala"
		_tmp73_ = gxml_dom_node_list_item (_tmp72_, 4);
#line 225 "GElementTest.vala"
		_tmp74_ = _tmp73_;
#line 225 "GElementTest.vala"
		_tmp75_ = gxml_dom_node_get_node_name (_tmp74_);
#line 225 "GElementTest.vala"
		_tmp76_ = _tmp75_;
#line 225 "GElementTest.vala"
		_tmp77_ = _tmp76_;
#line 225 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp77_, "child") == 0, "l1.item (4).node_name == \"child\"");
#line 225 "GElementTest.vala"
		_g_free0 (_tmp77_);
#line 225 "GElementTest.vala"
		_g_object_unref0 (_tmp74_);
#line 226 "GElementTest.vala"
		_tmp78_ = r;
#line 226 "GElementTest.vala"
		_tmp79_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp78_, "child[class]", &_inner_error0_);
#line 226 "GElementTest.vala"
		l2 = _tmp79_;
#line 226 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 226 "GElementTest.vala"
			_g_object_unref0 (l1);
#line 226 "GElementTest.vala"
			_g_object_unref0 (n4);
#line 226 "GElementTest.vala"
			_g_object_unref0 (n3);
#line 226 "GElementTest.vala"
			_g_object_unref0 (n2);
#line 226 "GElementTest.vala"
			_g_object_unref0 (n1);
#line 226 "GElementTest.vala"
			_g_object_unref0 (c5);
#line 226 "GElementTest.vala"
			_g_object_unref0 (c4);
#line 226 "GElementTest.vala"
			_g_object_unref0 (c3);
#line 226 "GElementTest.vala"
			_g_object_unref0 (c2);
#line 226 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 226 "GElementTest.vala"
			_g_object_unref0 (r);
#line 226 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3663 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 227 "GElementTest.vala"
		_tmp80_ = l2;
#line 227 "GElementTest.vala"
		_vala_assert (_tmp80_ != NULL, "l2 != null");
#line 228 "GElementTest.vala"
		_tmp81_ = l2;
#line 228 "GElementTest.vala"
		_tmp82_ = gxml_dom_node_list_get_length (_tmp81_);
#line 228 "GElementTest.vala"
		_tmp83_ = _tmp82_;
#line 228 "GElementTest.vala"
		_vala_assert (_tmp83_ == 4, "l2.length == 4");
#line 229 "GElementTest.vala"
		_tmp84_ = l2;
#line 229 "GElementTest.vala"
		_tmp85_ = gxml_dom_node_list_item (_tmp84_, 3);
#line 229 "GElementTest.vala"
		_tmp86_ = _tmp85_;
#line 229 "GElementTest.vala"
		_tmp87_ = gxml_dom_node_get_node_name (_tmp86_);
#line 229 "GElementTest.vala"
		_tmp88_ = _tmp87_;
#line 229 "GElementTest.vala"
		_tmp89_ = _tmp88_;
#line 229 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp89_, "child") == 0, "l2.item (3).node_name == \"child\"");
#line 229 "GElementTest.vala"
		_g_free0 (_tmp89_);
#line 229 "GElementTest.vala"
		_g_object_unref0 (_tmp86_);
#line 230 "GElementTest.vala"
		_tmp90_ = r;
#line 230 "GElementTest.vala"
		_tmp91_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp90_, "child[class=\"error\"]", &_inner_error0_);
#line 230 "GElementTest.vala"
		l3 = _tmp91_;
#line 230 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 230 "GElementTest.vala"
			_g_object_unref0 (l2);
#line 230 "GElementTest.vala"
			_g_object_unref0 (l1);
#line 230 "GElementTest.vala"
			_g_object_unref0 (n4);
#line 230 "GElementTest.vala"
			_g_object_unref0 (n3);
#line 230 "GElementTest.vala"
			_g_object_unref0 (n2);
#line 230 "GElementTest.vala"
			_g_object_unref0 (n1);
#line 230 "GElementTest.vala"
			_g_object_unref0 (c5);
#line 230 "GElementTest.vala"
			_g_object_unref0 (c4);
#line 230 "GElementTest.vala"
			_g_object_unref0 (c3);
#line 230 "GElementTest.vala"
			_g_object_unref0 (c2);
#line 230 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 230 "GElementTest.vala"
			_g_object_unref0 (r);
#line 230 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3730 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 231 "GElementTest.vala"
		_tmp92_ = l3;
#line 231 "GElementTest.vala"
		_vala_assert (_tmp92_ != NULL, "l3 != null");
#line 232 "GElementTest.vala"
		_tmp93_ = l3;
#line 232 "GElementTest.vala"
		_tmp94_ = gxml_dom_node_list_get_length (_tmp93_);
#line 232 "GElementTest.vala"
		_tmp95_ = _tmp94_;
#line 232 "GElementTest.vala"
		_vala_assert (_tmp95_ == 1, "l3.length == 1");
#line 233 "GElementTest.vala"
		_tmp96_ = l3;
#line 233 "GElementTest.vala"
		_tmp97_ = gxml_dom_node_list_item (_tmp96_, 0);
#line 233 "GElementTest.vala"
		_tmp98_ = _tmp97_;
#line 233 "GElementTest.vala"
		_tmp99_ = gxml_dom_node_get_node_name (_tmp98_);
#line 233 "GElementTest.vala"
		_tmp100_ = _tmp99_;
#line 233 "GElementTest.vala"
		_tmp101_ = _tmp100_;
#line 233 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp101_, "child") == 0, "l3.item (0).node_name == \"child\"");
#line 233 "GElementTest.vala"
		_g_free0 (_tmp101_);
#line 233 "GElementTest.vala"
		_g_object_unref0 (_tmp98_);
#line 234 "GElementTest.vala"
		_tmp102_ = d;
#line 234 "GElementTest.vala"
		_tmp103_ = gxml_dom_document_create_element (_tmp102_, "child", &_inner_error0_);
#line 234 "GElementTest.vala"
		c6 = _tmp103_;
#line 234 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 234 "GElementTest.vala"
			_g_object_unref0 (l3);
#line 234 "GElementTest.vala"
			_g_object_unref0 (l2);
#line 234 "GElementTest.vala"
			_g_object_unref0 (l1);
#line 234 "GElementTest.vala"
			_g_object_unref0 (n4);
#line 234 "GElementTest.vala"
			_g_object_unref0 (n3);
#line 234 "GElementTest.vala"
			_g_object_unref0 (n2);
#line 234 "GElementTest.vala"
			_g_object_unref0 (n1);
#line 234 "GElementTest.vala"
			_g_object_unref0 (c5);
#line 234 "GElementTest.vala"
			_g_object_unref0 (c4);
#line 234 "GElementTest.vala"
			_g_object_unref0 (c3);
#line 234 "GElementTest.vala"
			_g_object_unref0 (c2);
#line 234 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 234 "GElementTest.vala"
			_g_object_unref0 (r);
#line 234 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3799 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 235 "GElementTest.vala"
		_tmp104_ = c6;
#line 235 "GElementTest.vala"
		gxml_dom_element_set_attribute (_tmp104_, "prop", "val1", &_inner_error0_);
#line 235 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 235 "GElementTest.vala"
			_g_object_unref0 (c6);
#line 235 "GElementTest.vala"
			_g_object_unref0 (l3);
#line 235 "GElementTest.vala"
			_g_object_unref0 (l2);
#line 235 "GElementTest.vala"
			_g_object_unref0 (l1);
#line 235 "GElementTest.vala"
			_g_object_unref0 (n4);
#line 235 "GElementTest.vala"
			_g_object_unref0 (n3);
#line 235 "GElementTest.vala"
			_g_object_unref0 (n2);
#line 235 "GElementTest.vala"
			_g_object_unref0 (n1);
#line 235 "GElementTest.vala"
			_g_object_unref0 (c5);
#line 235 "GElementTest.vala"
			_g_object_unref0 (c4);
#line 235 "GElementTest.vala"
			_g_object_unref0 (c3);
#line 235 "GElementTest.vala"
			_g_object_unref0 (c2);
#line 235 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 235 "GElementTest.vala"
			_g_object_unref0 (r);
#line 235 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3838 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 236 "GElementTest.vala"
		_tmp105_ = r;
#line 236 "GElementTest.vala"
		_tmp106_ = c6;
#line 236 "GElementTest.vala"
		_tmp107_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp105_, (GXmlDomNode*) _tmp106_, &_inner_error0_);
#line 236 "GElementTest.vala"
		_tmp108_ = _tmp107_;
#line 236 "GElementTest.vala"
		_g_object_unref0 (_tmp108_);
#line 236 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 236 "GElementTest.vala"
			_g_object_unref0 (c6);
#line 236 "GElementTest.vala"
			_g_object_unref0 (l3);
#line 236 "GElementTest.vala"
			_g_object_unref0 (l2);
#line 236 "GElementTest.vala"
			_g_object_unref0 (l1);
#line 236 "GElementTest.vala"
			_g_object_unref0 (n4);
#line 236 "GElementTest.vala"
			_g_object_unref0 (n3);
#line 236 "GElementTest.vala"
			_g_object_unref0 (n2);
#line 236 "GElementTest.vala"
			_g_object_unref0 (n1);
#line 236 "GElementTest.vala"
			_g_object_unref0 (c5);
#line 236 "GElementTest.vala"
			_g_object_unref0 (c4);
#line 236 "GElementTest.vala"
			_g_object_unref0 (c3);
#line 236 "GElementTest.vala"
			_g_object_unref0 (c2);
#line 236 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 236 "GElementTest.vala"
			_g_object_unref0 (r);
#line 236 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3883 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 237 "GElementTest.vala"
		_tmp109_ = d;
#line 237 "GElementTest.vala"
		_tmp110_ = gxml_dom_document_create_element (_tmp109_, "child", &_inner_error0_);
#line 237 "GElementTest.vala"
		c7 = _tmp110_;
#line 237 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 237 "GElementTest.vala"
			_g_object_unref0 (c6);
#line 237 "GElementTest.vala"
			_g_object_unref0 (l3);
#line 237 "GElementTest.vala"
			_g_object_unref0 (l2);
#line 237 "GElementTest.vala"
			_g_object_unref0 (l1);
#line 237 "GElementTest.vala"
			_g_object_unref0 (n4);
#line 237 "GElementTest.vala"
			_g_object_unref0 (n3);
#line 237 "GElementTest.vala"
			_g_object_unref0 (n2);
#line 237 "GElementTest.vala"
			_g_object_unref0 (n1);
#line 237 "GElementTest.vala"
			_g_object_unref0 (c5);
#line 237 "GElementTest.vala"
			_g_object_unref0 (c4);
#line 237 "GElementTest.vala"
			_g_object_unref0 (c3);
#line 237 "GElementTest.vala"
			_g_object_unref0 (c2);
#line 237 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 237 "GElementTest.vala"
			_g_object_unref0 (r);
#line 237 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3924 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 238 "GElementTest.vala"
		_tmp111_ = c7;
#line 238 "GElementTest.vala"
		gxml_dom_element_set_attribute (_tmp111_, "prop", "val1", &_inner_error0_);
#line 238 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 238 "GElementTest.vala"
			_g_object_unref0 (c7);
#line 238 "GElementTest.vala"
			_g_object_unref0 (c6);
#line 238 "GElementTest.vala"
			_g_object_unref0 (l3);
#line 238 "GElementTest.vala"
			_g_object_unref0 (l2);
#line 238 "GElementTest.vala"
			_g_object_unref0 (l1);
#line 238 "GElementTest.vala"
			_g_object_unref0 (n4);
#line 238 "GElementTest.vala"
			_g_object_unref0 (n3);
#line 238 "GElementTest.vala"
			_g_object_unref0 (n2);
#line 238 "GElementTest.vala"
			_g_object_unref0 (n1);
#line 238 "GElementTest.vala"
			_g_object_unref0 (c5);
#line 238 "GElementTest.vala"
			_g_object_unref0 (c4);
#line 238 "GElementTest.vala"
			_g_object_unref0 (c3);
#line 238 "GElementTest.vala"
			_g_object_unref0 (c2);
#line 238 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 238 "GElementTest.vala"
			_g_object_unref0 (r);
#line 238 "GElementTest.vala"
			_g_object_unref0 (d);
#line 3965 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 239 "GElementTest.vala"
		_tmp112_ = r;
#line 239 "GElementTest.vala"
		_tmp113_ = c7;
#line 239 "GElementTest.vala"
		_tmp114_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp112_, (GXmlDomNode*) _tmp113_, &_inner_error0_);
#line 239 "GElementTest.vala"
		_tmp115_ = _tmp114_;
#line 239 "GElementTest.vala"
		_g_object_unref0 (_tmp115_);
#line 239 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 239 "GElementTest.vala"
			_g_object_unref0 (c7);
#line 239 "GElementTest.vala"
			_g_object_unref0 (c6);
#line 239 "GElementTest.vala"
			_g_object_unref0 (l3);
#line 239 "GElementTest.vala"
			_g_object_unref0 (l2);
#line 239 "GElementTest.vala"
			_g_object_unref0 (l1);
#line 239 "GElementTest.vala"
			_g_object_unref0 (n4);
#line 239 "GElementTest.vala"
			_g_object_unref0 (n3);
#line 239 "GElementTest.vala"
			_g_object_unref0 (n2);
#line 239 "GElementTest.vala"
			_g_object_unref0 (n1);
#line 239 "GElementTest.vala"
			_g_object_unref0 (c5);
#line 239 "GElementTest.vala"
			_g_object_unref0 (c4);
#line 239 "GElementTest.vala"
			_g_object_unref0 (c3);
#line 239 "GElementTest.vala"
			_g_object_unref0 (c2);
#line 239 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 239 "GElementTest.vala"
			_g_object_unref0 (r);
#line 239 "GElementTest.vala"
			_g_object_unref0 (d);
#line 4012 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 240 "GElementTest.vala"
		_tmp116_ = r;
#line 240 "GElementTest.vala"
		_tmp117_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp116_, "child[prop=\"val1\"]", &_inner_error0_);
#line 240 "GElementTest.vala"
		l4 = _tmp117_;
#line 240 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 240 "GElementTest.vala"
			_g_object_unref0 (c7);
#line 240 "GElementTest.vala"
			_g_object_unref0 (c6);
#line 240 "GElementTest.vala"
			_g_object_unref0 (l3);
#line 240 "GElementTest.vala"
			_g_object_unref0 (l2);
#line 240 "GElementTest.vala"
			_g_object_unref0 (l1);
#line 240 "GElementTest.vala"
			_g_object_unref0 (n4);
#line 240 "GElementTest.vala"
			_g_object_unref0 (n3);
#line 240 "GElementTest.vala"
			_g_object_unref0 (n2);
#line 240 "GElementTest.vala"
			_g_object_unref0 (n1);
#line 240 "GElementTest.vala"
			_g_object_unref0 (c5);
#line 240 "GElementTest.vala"
			_g_object_unref0 (c4);
#line 240 "GElementTest.vala"
			_g_object_unref0 (c3);
#line 240 "GElementTest.vala"
			_g_object_unref0 (c2);
#line 240 "GElementTest.vala"
			_g_object_unref0 (c1);
#line 240 "GElementTest.vala"
			_g_object_unref0 (r);
#line 240 "GElementTest.vala"
			_g_object_unref0 (d);
#line 4055 "GElementTest.c"
			goto __catch51_g_error;
		}
#line 241 "GElementTest.vala"
		_tmp118_ = l4;
#line 241 "GElementTest.vala"
		_vala_assert (_tmp118_ != NULL, "l4 != null");
#line 242 "GElementTest.vala"
		_tmp119_ = l4;
#line 242 "GElementTest.vala"
		_tmp120_ = gxml_dom_node_list_get_length (_tmp119_);
#line 242 "GElementTest.vala"
		_tmp121_ = _tmp120_;
#line 242 "GElementTest.vala"
		_vala_assert (_tmp121_ == 2, "l4.length == 2");
#line 243 "GElementTest.vala"
		_tmp122_ = l4;
#line 243 "GElementTest.vala"
		_tmp123_ = gxml_dom_node_list_item (_tmp122_, 0);
#line 243 "GElementTest.vala"
		_tmp124_ = _tmp123_;
#line 243 "GElementTest.vala"
		_tmp125_ = gxml_dom_node_get_node_name (_tmp124_);
#line 243 "GElementTest.vala"
		_tmp126_ = _tmp125_;
#line 243 "GElementTest.vala"
		_tmp127_ = _tmp126_;
#line 243 "GElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp127_, "child") == 0, "l4.item (0).node_name == \"child\"");
#line 243 "GElementTest.vala"
		_g_free0 (_tmp127_);
#line 243 "GElementTest.vala"
		_g_object_unref0 (_tmp124_);
#line 192 "GElementTest.vala"
		_g_object_unref0 (l4);
#line 192 "GElementTest.vala"
		_g_object_unref0 (c7);
#line 192 "GElementTest.vala"
		_g_object_unref0 (c6);
#line 192 "GElementTest.vala"
		_g_object_unref0 (l3);
#line 192 "GElementTest.vala"
		_g_object_unref0 (l2);
#line 192 "GElementTest.vala"
		_g_object_unref0 (l1);
#line 192 "GElementTest.vala"
		_g_object_unref0 (n4);
#line 192 "GElementTest.vala"
		_g_object_unref0 (n3);
#line 192 "GElementTest.vala"
		_g_object_unref0 (n2);
#line 192 "GElementTest.vala"
		_g_object_unref0 (n1);
#line 192 "GElementTest.vala"
		_g_object_unref0 (c5);
#line 192 "GElementTest.vala"
		_g_object_unref0 (c4);
#line 192 "GElementTest.vala"
		_g_object_unref0 (c3);
#line 192 "GElementTest.vala"
		_g_object_unref0 (c2);
#line 192 "GElementTest.vala"
		_g_object_unref0 (c1);
#line 192 "GElementTest.vala"
		_g_object_unref0 (r);
#line 192 "GElementTest.vala"
		_g_object_unref0 (d);
#line 4122 "GElementTest.c"
	}
	goto __finally51;
	__catch51_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp128_;
		gchar* _tmp129_;
		gchar* _tmp130_;
#line 192 "GElementTest.vala"
		e = _inner_error0_;
#line 192 "GElementTest.vala"
		_inner_error0_ = NULL;
#line 245 "GElementTest.vala"
		_tmp128_ = e->message;
#line 245 "GElementTest.vala"
		_tmp129_ = g_strconcat ("Error: ", _tmp128_, NULL);
#line 245 "GElementTest.vala"
		_tmp130_ = _tmp129_;
#line 245 "GElementTest.vala"
		g_message ("GElementTest.vala:245: %s", _tmp130_);
#line 245 "GElementTest.vala"
		_g_free0 (_tmp130_);
#line 246 "GElementTest.vala"
		g_assert_not_reached ();
#line 192 "GElementTest.vala"
		_g_error_free0 (e);
#line 4149 "GElementTest.c"
	}
	__finally51:
#line 192 "GElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 192 "GElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 192 "GElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 192 "GElementTest.vala"
		return;
#line 4160 "GElementTest.c"
	}
}

static void
___lambda36__gtest_func (void)
{
#line 191 "GElementTest.vala"
	__lambda36_ ();
#line 4169 "GElementTest.c"
}

static void
__lambda37_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		GXmlDomDocument* d = NULL;
		GXmlGDocument* _tmp0_;
		GFile* dir = NULL;
		GFile* _tmp1_;
		GFile* f = NULL;
		gchar* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		GFile* _tmp6_;
		GFile* _tmp7_;
#line 251 "GElementTest.vala"
		_tmp0_ = gxml_gdocument_new ();
#line 251 "GElementTest.vala"
		d = (GXmlDomDocument*) _tmp0_;
#line 252 "GElementTest.vala"
		_tmp1_ = g_file_new_for_path (TEST_DIR);
#line 252 "GElementTest.vala"
		dir = _tmp1_;
#line 253 "GElementTest.vala"
		_vala_assert (g_file_query_exists (dir, NULL), "dir.query_exists ()");
#line 254 "GElementTest.vala"
		_tmp2_ = g_file_get_uri (dir);
#line 254 "GElementTest.vala"
		_tmp3_ = _tmp2_;
#line 254 "GElementTest.vala"
		_tmp4_ = g_strconcat (_tmp3_, "/test-large.xml", NULL);
#line 254 "GElementTest.vala"
		_tmp5_ = _tmp4_;
#line 254 "GElementTest.vala"
		_tmp6_ = g_file_new_for_uri (_tmp5_);
#line 254 "GElementTest.vala"
		_tmp7_ = _tmp6_;
#line 254 "GElementTest.vala"
		_g_free0 (_tmp5_);
#line 254 "GElementTest.vala"
		_g_free0 (_tmp3_);
#line 254 "GElementTest.vala"
		f = _tmp7_;
#line 255 "GElementTest.vala"
		_vala_assert (g_file_query_exists (f, NULL), "f.query_exists ()");
#line 256 "GElementTest.vala"
		gxml_dom_document_read_from_file (d, f, NULL, &_inner_error0_);
#line 256 "GElementTest.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 256 "GElementTest.vala"
			_g_object_unref0 (f);
#line 256 "GElementTest.vala"
			_g_object_unref0 (dir);
#line 256 "GElementTest.vala"
			_g_object_unref0 (d);
#line 4228 "GElementTest.c"
			goto __catch52_g_error;
		}
#line 250 "GElementTest.vala"
		_g_object_unref0 (f);
#line 250 "GElementTest.vala"
		_g_object_unref0 (dir);
#line 250 "GElementTest.vala"
		_g_object_unref0 (d);
#line 4237 "GElementTest.c"
	}
	goto __finally52;
	__catch52_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp8_;
#line 250 "GElementTest.vala"
		e = _inner_error0_;
#line 250 "GElementTest.vala"
		_inner_error0_ = NULL;
#line 258 "GElementTest.vala"
		_tmp8_ = e->message;
#line 258 "GElementTest.vala"
		g_warning ("GElementTest.vala:258: Error: %s", _tmp8_);
#line 259 "GElementTest.vala"
		g_assert_not_reached ();
#line 250 "GElementTest.vala"
		_g_error_free0 (e);
#line 4256 "GElementTest.c"
	}
	__finally52:
#line 250 "GElementTest.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 250 "GElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 250 "GElementTest.vala"
		g_clear_error (&_inner_error0_);
#line 250 "GElementTest.vala"
		return;
#line 4267 "GElementTest.c"
	}
}

static void
___lambda37__gtest_func (void)
{
#line 249 "GElementTest.vala"
	__lambda37_ ();
#line 4276 "GElementTest.c"
}

void
gelement_test_add_tests (void)
{
#line 27 "GElementTest.vala"
	g_test_add_func ("/gxml/gelement/namespace_uri", ___lambda28__gtest_func);
#line 47 "GElementTest.vala"
	g_test_add_func ("/gxml/gelement/attributes", ___lambda29__gtest_func);
#line 80 "GElementTest.vala"
	g_test_add_func ("/gxml/gelement/to_string", ___lambda30__gtest_func);
#line 99 "GElementTest.vala"
	g_test_add_func ("/gxml/gelement/content/set", ___lambda31__gtest_func);
#line 113 "GElementTest.vala"
	g_test_add_func ("/gxml/gelement/content/add_aside_child_nodes", ___lambda32__gtest_func);
#line 130 "GElementTest.vala"
	g_test_add_func ("/gxml/gelement/content/keep_child_nodes", ___lambda33__gtest_func);
#line 146 "GElementTest.vala"
	g_test_add_func ("/gxml/gelement/parent", ___lambda34__gtest_func);
#line 160 "GElementTest.vala"
	g_test_add_func ("/gxml/gelement/previous_element_sibling", ___lambda35__gtest_func);
#line 191 "GElementTest.vala"
	g_test_add_func ("/gxml/gelement/css-selector", ___lambda36__gtest_func);
#line 249 "GElementTest.vala"
	g_test_add_func ("/gxml/g-document/dom-write-read", ___lambda37__gtest_func);
#line 4302 "GElementTest.c"
}

GElementTest*
gelement_test_construct (GType object_type)
{
	GElementTest* self = NULL;
#line 25 "GElementTest.vala"
	self = (GElementTest*) gxml_test_construct (object_type);
#line 25 "GElementTest.vala"
	return self;
#line 4313 "GElementTest.c"
}

GElementTest*
gelement_test_new (void)
{
#line 25 "GElementTest.vala"
	return gelement_test_construct (TYPE_GELEMENT_TEST);
#line 4321 "GElementTest.c"
}

static void
gelement_test_class_init (GElementTestClass * klass,
                          gpointer klass_data)
{
#line 25 "GElementTest.vala"
	gelement_test_parent_class = g_type_class_peek_parent (klass);
#line 4330 "GElementTest.c"
}

static void
gelement_test_instance_init (GElementTest * self,
                             gpointer klass)
{
}

GType
gelement_test_get_type (void)
{
	static volatile gsize gelement_test_type_id__volatile = 0;
	if (g_once_init_enter (&gelement_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GElementTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gelement_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GElementTest), 0, (GInstanceInitFunc) gelement_test_instance_init, NULL };
		GType gelement_test_type_id;
		gelement_test_type_id = g_type_register_static (TYPE_GXML_TEST, "GElementTest", &g_define_type_info, 0);
		g_once_init_leave (&gelement_test_type_id__volatile, gelement_test_type_id);
	}
	return gelement_test_type_id__volatile;
}

static void
_vala_array_destroy (gpointer array,
                     gint array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gint array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

static gint
_vala_array_length (gpointer array)
{
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}

